# Generated by Django 2.2.24 on 2021-11-08 19:08

import django.db.models.deletion
from django.db import migrations

import sentry.db.models.fields.foreignkey
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar


def delete_code_mappings_with_no_integration(apps, schema_editor):
    """
    Delete the rows in the RepositoryProjectPathConfig table that have null organization_integration_id.
    """
    RepositoryProjectPathConfig = apps.get_model("sentry", "RepositoryProjectPathConfig")

    for code_mapping in RangeQuerySetWrapperWithProgressBar(
        RepositoryProjectPathConfig.objects.all()
    ):
        if code_mapping.organization_integration_id is None:
            code_mapping.delete()


class Migration(migrations.Migration):
    # This flag is used to mark that a migration shouldn't be automatically run in
    # production. We set this to True for operations that we think are risky and want
    # someone from ops to run manually and monitor.
    # General advice is that if in doubt, mark your migration as `is_dangerous`.
    # Some things you should always mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that
    #   they can be monitored. Since data migrations will now hold a transaction open
    #   this is even more important.
    # - Adding columns to highly active tables, even ones that are NULL.
    is_dangerous = True

    # This flag is used to decide whether to run this migration in a transaction or not.
    # By default we prefer to run in a transaction, but for migrations where you want
    # to `CREATE INDEX CONCURRENTLY` this needs to be set to False. Typically you'll
    # want to create an index concurrently when adding one to an existing table.
    # You'll also usually want to set this to `False` if you're writing a data
    # migration, since we don't want the entire migration to run in one long-running
    # transaction.
    atomic = False

    dependencies = [
        ("sentry", "0251_sentryappavatar_sentryapp_not_unique"),
    ]

    operations = [
        migrations.SeparateDatabaseAndState(
            database_operations=[
                migrations.RunPython(
                    delete_code_mappings_with_no_integration,
                    migrations.RunPython.noop,
                    hints={"tables": ["sentry_repositoryprojectpathconfig"]},
                ),
                migrations.AlterField(
                    model_name="repositoryprojectpathconfig",
                    name="organization_integration",
                    field=sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="sentry.OrganizationIntegration",
                        null=False,
                    ),
                ),
            ],
            state_operations=[
                migrations.AlterField(
                    model_name="repositoryprojectpathconfig",
                    name="organization_integration",
                    field=sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="sentry.OrganizationIntegration",
                        null=False,
                    ),
                )
            ],
        )
    ]
