# Generated by Django 2.2.28 on 2022-06-30 23:56

from django.db import migrations

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar

# Keys from `Dataset`, values from `AlertRule.Type`
dataset_to_type_map = {
    "events": 0,
    "transactions": 1,
    # There are some inactive alert rules that still have `sessions` as their dataset. We want to
    # still fill in type for these rows
    "sessions": 2,
    "metrics": 2,
}


def backfill_alertrule_type(apps, schema_editor):
    AlertRule = apps.get_model("sentry", "AlertRule")

    for alert_rule in RangeQuerySetWrapperWithProgressBar(
        AlertRule.objects_with_snapshots.select_related("snuba_query").all()
    ):
        if alert_rule.type is not None or alert_rule.snuba_query is None:
            continue

        alert_rule.type = dataset_to_type_map[alert_rule.snuba_query.dataset]
        alert_rule.save(update_fields=["type"])


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_dangerous = False

    # This flag is used to decide whether to run this migration in a transaction or not. Generally
    # we don't want to run in a transaction here, since for long running operations like data
    # back-fills this results in us locking an increasing number of rows until we finally commit.
    atomic = False

    dependencies = [
        ("sentry", "0294_alertrule_type"),
    ]

    operations = [
        migrations.RunPython(
            backfill_alertrule_type,
            migrations.RunPython.noop,
            hints={"tables": ["sentry_alertrule"]},
        ),
    ]
