# Generated by Django 2.2.28 on 2022-07-27 22:54

import django.db.models.deletion
from django.db import migrations, models

import sentry.db.models.fields.bounded
import sentry.db.models.fields.foreignkey
from sentry.new_migrations.migrations import CheckedMigration


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.

    # this doesn't need to be run in prod as the db fields are already bigints
    is_dangerous = True

    # This flag is used to decide whether to run this migration in a transaction or not. Generally
    # we don't want to run in a transaction here, since for long running operations like data
    # back-fills this results in us locking an increasing number of rows until we finally commit.
    atomic = False

    dependencies = [
        ("sentry", "0308_remove_alert_type_column"),
    ]

    operations = [
        migrations.SeparateDatabaseAndState(
            database_operations=[],
            state_operations=[
                migrations.CreateModel(
                    name="AuthProviderDefaultTeams",
                    fields=[
                        (
                            "id",
                            sentry.db.models.fields.bounded.BoundedBigAutoField(
                                primary_key=True, serialize=False
                            ),
                        ),
                    ],
                    options={
                        "db_table": "sentry_authprovider_default_teams",
                    },
                ),
                migrations.CreateModel(
                    name="DashboardProject",
                    fields=[
                        (
                            "id",
                            sentry.db.models.fields.bounded.BoundedBigAutoField(
                                primary_key=True, serialize=False
                            ),
                        ),
                    ],
                    options={
                        "db_table": "sentry_dashboardproject",
                    },
                ),
                migrations.AlterField(
                    model_name="authprovider",
                    name="default_teams",
                    field=models.ManyToManyField(
                        blank=True, through="sentry.AuthProviderDefaultTeams", to="sentry.Team"
                    ),
                ),
                migrations.AlterField(
                    model_name="dashboard",
                    name="projects",
                    field=models.ManyToManyField(
                        through="sentry.DashboardProject", to="sentry.Project"
                    ),
                ),
                migrations.AddField(
                    model_name="dashboardproject",
                    name="dashboard",
                    field=sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="sentry.Dashboard"
                    ),
                ),
                migrations.AddField(
                    model_name="dashboardproject",
                    name="project",
                    field=sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="sentry.Project"
                    ),
                ),
                migrations.AddField(
                    model_name="authproviderdefaultteams",
                    name="authprovider",
                    field=sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="sentry.AuthProvider"
                    ),
                ),
                migrations.AddField(
                    model_name="authproviderdefaultteams",
                    name="team",
                    field=sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="sentry.Team"
                    ),
                ),
                migrations.AlterUniqueTogether(
                    name="dashboardproject",
                    unique_together={("project", "dashboard")},
                ),
                migrations.AlterUniqueTogether(
                    name="authproviderdefaultteams",
                    unique_together={("authprovider", "team")},
                ),
            ],
        ),
        migrations.RunSQL(
            sql="ALTER TABLE sentry_authprovider_default_teams ALTER COLUMN id TYPE bigint",
            hints={"tables": ["sentry_authprovider_default_teams"]},
            reverse_sql="ALTER TABLE sentry_authprovider_default_teams ALTER COLUMN id TYPE int",
        ),
        migrations.RunSQL(
            sql="ALTER TABLE sentry_authprovider_default_teams ALTER COLUMN authprovider_id TYPE bigint",
            hints={"tables": ["sentry_authprovider_default_teams"]},
            reverse_sql="ALTER TABLE sentry_authprovider_default_teams ALTER COLUMN authprovider_id TYPE int",
        ),
        migrations.RunSQL(
            sql="ALTER TABLE sentry_authprovider_default_teams ALTER COLUMN team_id TYPE bigint",
            hints={"tables": ["sentry_authprovider_default_teams"]},
            reverse_sql="ALTER TABLE sentry_authprovider_default_teams ALTER COLUMN team_id TYPE int",
        ),
        migrations.RunSQL(
            sql="ALTER TABLE sentry_dashboardproject ALTER COLUMN id TYPE bigint",
            hints={"tables": ["sentry_dashboardproject"]},
            reverse_sql="ALTER TABLE sentry_dashboardproject ALTER COLUMN id TYPE int",
        ),
        migrations.RunSQL(
            sql="ALTER TABLE sentry_dashboardproject ALTER COLUMN id TYPE bigint",
            hints={"tables": ["sentry_dashboardproject"]},
            reverse_sql="ALTER TABLE sentry_dashboardproject ALTER COLUMN dashboard_id TYPE int",
        ),
        migrations.RunSQL(
            sql="ALTER TABLE sentry_dashboardproject ALTER COLUMN id TYPE bigint",
            hints={"tables": ["sentry_dashboardproject"]},
            reverse_sql="ALTER TABLE sentry_dashboardproject ALTER COLUMN project_id TYPE int",
        ),
    ]
