# Generated by Django 2.2.28 on 2023-01-31 20:37

from django.db import IntegrityError, migrations
from django.db.models.functions import Lower

from sentry.constants import RESERVED_ORGANIZATION_SLUGS
from sentry.db.models.utils import slugify_instance
from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar


def fix_org_slug_casing(apps, schema_editor):
    Organization = apps.get_model("sentry", "Organization")
    query = Organization.objects.exclude(slug=Lower("slug"))
    for org in RangeQuerySetWrapperWithProgressBar(query):
        try:
            org.slug = org.slug.lower()
            org.save(update_fields=["slug"])
        except IntegrityError:
            slugify_instance(org, org.slug, reserved=RESERVED_ORGANIZATION_SLUGS)
            org.save(update_fields=["slug"])


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_dangerous = False

    dependencies = [
        ("sentry", "0380_backfill_monitor_env_initial"),
    ]

    operations = [
        migrations.RunPython(
            fix_org_slug_casing,
            reverse_code=migrations.RunPython.noop,
            hints={"tables": ["sentry_organization"]},
        )
    ]
