# Generated by Django 2.2.28 on 2023-03-09 23:03

from django.db import migrations

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar


def backfill_installation_ids(apps, schema_editor):
    ServiceHook = apps.get_model("sentry", "ServiceHook")

    # The actor id for all ServiceHooks where a project id is not specified is the installation id,
    # but other actor ids are user ids.
    queryset = RangeQuerySetWrapperWithProgressBar(
        ServiceHook.objects.filter(project_id__isnull=True)
    )
    for hook in queryset:
        hook.installation_id = hook.actor_id
        hook.save()


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_dangerous = False

    dependencies = [
        ("sentry", "0383_mv_user_avatar"),
    ]

    operations = [
        migrations.RunPython(
            backfill_installation_ids,
            migrations.RunPython.noop,
            hints={
                "tables": [
                    "sentry_servicehook",
                ]
            },
        ),
    ]
