# Generated by Django 2.2.28 on 2023-03-22 07:55

import django.utils.timezone
from django.db import migrations, models

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar


def copy_date_added_to_date_uploaded(apps, schema_editor):
    ArtifactBundle = apps.get_model("sentry", "ArtifactBundle")

    for bundle in RangeQuerySetWrapperWithProgressBar(
        ArtifactBundle.objects.filter(date_uploaded__isnull=True)
    ):
        bundle.date_uploaded = bundle.date_added
        bundle.save(update_fields=["date_uploaded"])


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_dangerous = False
    checked = False

    dependencies = [
        ("sentry", "0393_create_groupforecast_table"),
    ]

    operations = [
        migrations.SeparateDatabaseAndState(
            database_operations=[
                migrations.RunPython(
                    copy_date_added_to_date_uploaded,
                    migrations.RunPython.noop,
                    hints={"tables": ["sentry_artifactbundle"]},
                ),
                migrations.AlterField(
                    model_name="artifactbundle",
                    name="date_uploaded",
                    field=models.DateTimeField(),
                ),
            ],
            state_operations=[
                migrations.AlterField(
                    model_name="artifactbundle",
                    name="date_uploaded",
                    field=models.DateTimeField(default=django.utils.timezone.now),
                ),
            ],
        ),
    ]
