# Generated by Django 2.2.28 on 2023-01-31 20:37

from django.db import migrations

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar


def backfill_organization_integration_denormalization(apps, schema_editor):
    PagerDutyService = apps.get_model("sentry", "PagerDutyService")
    RepositoryProjectPathConfig = apps.get_model("sentry", "RepositoryProjectPathConfig")
    OrganizationIntegration = apps.get_model("sentry", "OrganizationIntegration")

    def backfill(self) -> None:
        if self.organization_id is None or self.integration_id is None:
            # Find the original org integration instance, backfill in the identifiers.
            oi = OrganizationIntegration.objects.get(id=self.organization_integration_id)
            self.organization_id = oi.organization_id
            self.integration_id = oi.integration_id
        self.save()

    for obj in RangeQuerySetWrapperWithProgressBar(PagerDutyService.objects.all()):
        backfill(obj)
    for obj in RangeQuerySetWrapperWithProgressBar(RepositoryProjectPathConfig.objects.all()):
        backfill(obj)


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_dangerous = True

    dependencies = [
        ("sentry", "0412_org_integration_denormalization"),
    ]

    operations = [
        migrations.RunPython(
            backfill_organization_integration_denormalization,
            reverse_code=migrations.RunPython.noop,
            hints={"tables": ["pagerdutyservice", "repositoryprojectpathconfig"]},
        ),
    ]
