# Generated by Django 2.2.28 on 2023-04-28 23:49

from django.db import migrations

from sentry.new_migrations.migrations import CheckedMigration


def set_monitor_status_to_object_status_only(apps, schema_editor):
    Monitor = apps.get_model("sentry", "Monitor")

    # 0, 1, 2, 3 are the default ObjectStatus values, status's outside of
    # that are the extended status from the monitor.
    for monitor in Monitor.objects.exclude(status__in=(0, 1, 2, 3)):
        # Active / Visible status
        monitor.status = 0
        monitor.save(update_fields=["status"])


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_dangerous = False

    dependencies = [
        ("sentry", "0432_backfill_org_member_id_organizationmembermapping"),
    ]

    operations = [
        migrations.RunPython(
            set_monitor_status_to_object_status_only,
            reverse_code=migrations.RunPython.noop,
            hints={"tables": ["sentry_monitor"]},
        ),
    ]
