# Generated by Django 2.2.28 on 2023-07-06 22:52

from django.db import migrations

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar


class ObjectStatus:
    VISIBLE = 0
    HIDDEN = 1
    PENDING_DELETION = 2
    DELETION_IN_PROGRESS = 3

    ACTIVE = 0
    DISABLED = 1


def schedule(cls, instance, days=30):
    from datetime import timedelta

    from django.utils import timezone

    model = type(instance)
    model_name = model.__name__
    cls.objects.update_or_create(
        app_label=instance._meta.app_label,
        model_name=model_name,
        object_id=instance.pk,
        defaults={
            "actor_id": None,
            "data": {},
            "date_scheduled": timezone.now() + timedelta(days=days, hours=0),
        },
    )


def delete_rules(apps, schema_editor):
    Rule = apps.get_model("sentry", "Rule")
    RegionScheduledDeletion = apps.get_model("sentry", "RegionScheduledDeletion")
    for rule in RangeQuerySetWrapperWithProgressBar(Rule.objects.all()):
        if rule.status in (ObjectStatus.PENDING_DELETION, ObjectStatus.DISABLED):
            schedule(RegionScheduledDeletion, rule, days=0)


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_dangerous = True

    dependencies = [
        ("sentry", "0506_null_boolean_fields"),
    ]

    operations = [
        migrations.RunPython(
            delete_rules,
            migrations.RunPython.noop,
            hints={"tables": ["sentry_rule"]},
        ),
    ]
