# Generated by Django 3.2.20 on 2023-08-01 20:51

from django.db import migrations

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar


def backfill_next_checkin_latest(apps, schema_editor):
    MonitorEnvironment = apps.get_model("sentry", "MonitorEnvironment")

    for monitor_environment in RangeQuerySetWrapperWithProgressBar(
        MonitorEnvironment.objects.all()
    ):
        # skip backfill if next_checkin_latest is set or next_checkin is not set
        if (
            monitor_environment.next_checkin_latest is not None
            or monitor_environment.next_checkin is None
        ):
            continue

        monitor_environment.next_checkin_latest = monitor_environment.next_checkin
        monitor_environment.save(update_fields=["next_checkin_latest"])


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_dangerous = False

    dependencies = [
        ("sentry", "0526_pr_comment_type_column"),
    ]

    operations = [
        migrations.RunPython(
            backfill_next_checkin_latest,
            migrations.RunPython.noop,
            hints={"tables": ["sentry_monitorenvironment"]},
        ),
    ]
