# Generated by Django 3.2.20 on 2023-09-20 00:47

from django.db import migrations

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar


def remove_missed_margins_zero(apps, schema_editor):
    Monitor = apps.get_model("sentry", "Monitor")
    for monitor in RangeQuerySetWrapperWithProgressBar(Monitor.objects.all()):
        margin = monitor.config.get("checkin_margin")

        # Update monitors with an explicit `0` margin to None. This is
        # equevilent of not setting the value. See GH-56526
        if margin == 0:
            monitor.config["checkin_margin"] = None
            monitor.save()


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_dangerous = False

    dependencies = [
        ("sentry", "0565_fix_diff_env_dupe_alerts"),
    ]

    operations = [
        migrations.RunPython(
            remove_missed_margins_zero,
            migrations.RunPython.noop,
            hints={"tables": ["sentry_monitor"]},
        ),
    ]
