# Generated by Django 3.2.20 on 2023-11-02 19:44

import django.db.models.deletion
import django.utils.timezone
from django.db import migrations, models

import sentry.db.models.fields.bounded
import sentry.db.models.fields.foreignkey
import sentry.db.models.fields.hybrid_cloud_foreign_key
import sentry.db.models.fields.uuid
import sentry.models.relocation
from sentry.new_migrations.migrations import CheckedMigration


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as dangerous:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_dangerous = False

    dependencies = [
        ("sentry", "0587_remove_unused_neglectedrule_rows"),
    ]

    operations = [
        migrations.CreateModel(
            name="Relocation",
            fields=[
                (
                    "id",
                    sentry.db.models.fields.bounded.BoundedBigAutoField(
                        primary_key=True, serialize=False
                    ),
                ),
                ("date_updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("date_added", models.DateTimeField(default=django.utils.timezone.now, null=True)),
                (
                    "creator",
                    sentry.db.models.fields.hybrid_cloud_foreign_key.HybridCloudForeignKey(
                        "sentry.User", db_index=True, null=True, on_delete="SET_NULL"
                    ),
                ),
                (
                    "owner",
                    sentry.db.models.fields.hybrid_cloud_foreign_key.HybridCloudForeignKey(
                        "sentry.User", db_index=True, null=True, on_delete="SET_NULL"
                    ),
                ),
                (
                    "uuid",
                    sentry.db.models.fields.uuid.UUIDField(
                        db_index=True,
                        default=sentry.models.relocation.default_guid,
                        max_length=32,
                        unique=True,
                    ),
                ),
                ("step", models.SmallIntegerField(default=None)),
                ("status", models.SmallIntegerField(default=0)),
                ("want_org_slugs", models.JSONField(default=list)),
                ("want_usernames", models.JSONField(null=True)),
                ("latest_notified", models.SmallIntegerField(default=None, null=True)),
                ("latest_task", models.CharField(default="", max_length=64)),
                ("latest_task_attempts", models.SmallIntegerField(default=0)),
                ("failure_reason", models.CharField(default=None, max_length=256, null=True)),
            ],
            options={
                "db_table": "sentry_relocation",
            },
        ),
        migrations.CreateModel(
            name="RelocationValidation",
            fields=[
                (
                    "id",
                    sentry.db.models.fields.bounded.BoundedBigAutoField(
                        primary_key=True, serialize=False
                    ),
                ),
                ("date_updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("date_added", models.DateTimeField(default=django.utils.timezone.now, null=True)),
                ("status", models.SmallIntegerField(default=0)),
                ("attempts", models.SmallIntegerField(default=0)),
                (
                    "relocation",
                    sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="sentry.relocation"
                    ),
                ),
            ],
            options={
                "db_table": "sentry_relocationvalidation",
            },
        ),
        migrations.CreateModel(
            name="RelocationValidationAttempt",
            fields=[
                (
                    "id",
                    sentry.db.models.fields.bounded.BoundedBigAutoField(
                        primary_key=True, serialize=False
                    ),
                ),
                ("date_updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("date_added", models.DateTimeField(default=django.utils.timezone.now, null=True)),
                ("status", models.SmallIntegerField(default=0)),
                (
                    "build_id",
                    sentry.db.models.fields.uuid.UUIDField(
                        db_index=True, max_length=32, unique=True
                    ),
                ),
                (
                    "relocation",
                    sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="sentry.relocation"
                    ),
                ),
                (
                    "relocation_validation",
                    sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="sentry.relocationvalidation",
                    ),
                ),
            ],
            options={
                "db_table": "sentry_relocationvalidationattempt",
            },
        ),
        migrations.CreateModel(
            name="RelocationFile",
            fields=[
                (
                    "id",
                    sentry.db.models.fields.bounded.BoundedBigAutoField(
                        primary_key=True, serialize=False
                    ),
                ),
                ("date_updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("date_added", models.DateTimeField(default=django.utils.timezone.now, null=True)),
                ("kind", models.SmallIntegerField()),
                (
                    "file",
                    sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="sentry.file"
                    ),
                ),
                (
                    "relocation",
                    sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="sentry.relocation"
                    ),
                ),
            ],
            options={
                "db_table": "sentry_relocationfile",
                "unique_together": {("relocation", "file")},
            },
        ),
    ]
