import {css, keyframes} from '@emotion/react';
import styled from '@emotion/styled';
import {motion} from 'framer-motion';

import {makeOpacityJitter, makeShake} from 'sentry/styles/animations';
import testableTransition from 'sentry/utils/testableTransition';

const Background = styled(motion.g)``;

Background.defaultProps = {
  initial: {opacity: 0},
  animate: {opacity: 1},
  transition: testableTransition({duration: 0.5}),
};

const MainWindows = styled(motion.g)``;

MainWindows.defaultProps = {
  initial: {rotate: -2, scale: 0.95, opacity: 0},
  animate: {rotate: 0, scale: 1, opacity: 1},
  transition: testableTransition({type: 'spring', delay: 0.2, stiffness: 200, bounce: 5}),
};

const SecondWindow = styled(motion.g)``;

SecondWindow.defaultProps = {
  initial: {rotate: 10, scale: 0.9, opacity: 0},
  animate: {rotate: 0, scale: 1, opacity: 1},
  transition: testableTransition({type: 'spring', delay: 0.7, stiffness: 200, bounce: 5}),
};

const Alert = styled(motion.g)`
  opacity: 0;
`;

const Spinner = styled(motion.g)`
  opacity: 0;
`;

const cableAnimate = {
  initial: {'--completed': 0} as any,
  animate: {'--completed': 1} as any,
};

const Cable = styled(motion.path)`
  stroke-dasharray: var(--stroke-length);
  stroke-dashoffset: calc(var(--stroke-length) * (1 - var(--completed, 0)));
`;

// All stroke lengths are computed using SVGGeometryElement.getTotalLength()
const CablePlug = styled(Cable)``;
CablePlug.defaultProps = {
  ...cableAnimate,
  style: {'--stroke-length': 717.05} as any,
  transition: testableTransition({duration: 2, delay: 1.3}),
};

const CableWindow1 = styled(Cable)``;
CableWindow1.defaultProps = {
  ...cableAnimate,
  custom: {length: 89.28},
  style: {'--stroke-length': 89.28} as any,
  transition: testableTransition({duration: 0.8, delay: 0.9}),
};

const CableWindow2 = styled(Cable)``;
CableWindow2.defaultProps = {
  ...cableAnimate,
  style: {'--stroke-length': 132.26} as any,
  transition: testableTransition({duration: 0.9, delay: 1}),
};

const PowerBolts = styled(motion.g)``;
PowerBolts.defaultProps = {
  initial: {rotate: 10, scale: 0.9, opacity: 0},
  animate: {rotate: 0, scale: 1, opacity: 1},
  transition: testableTransition({type: 'spring', delay: 3.2, stiffness: 200, bounce: 5}),
};

const PowerBolt = styled(motion.g)`
  animation-duration: 3.5s;
  animation-iteration-count: infinite;
`;

const Sparks = styled(motion.g)``;
Sparks.defaultProps = {
  initial: 'initial',
  animate: 'animate',
  variants: {
    animate: {
      x: 0,
      transition: testableTransition({
        when: 'beforeChildren',
        delay: 3.6,
        staggerChildren: 0.2,
      }),
    },
  },
};

const Spark = styled(motion.g)`
  animation-duration: 6s;
  animation-iteration-count: infinite;
`;

Spark.defaultProps = {
  variants: {
    initial: () => ({
      rotate: (Math.random() - 0.5) * 80,
      scale: 0.2,
      opacity: 0,
      display: 'none',
    }),
    animate: {
      rotate: 0,
      scale: 1,
      opacity: 1,
      display: 'block',
    },
  },
  transition: testableTransition({type: 'spring', stiffness: 500, bounce: 80}),
};

const oilSpill = keyframes`
  0% {
    opacity: 0;
    transform: scale(0.4);
  }
  10% {
    opacity: 1;
  }
  95% {
    opacity: 1;
    transform: scale(1);
  }
  100% {
    opacity: 0;
  }
`;

const OilPuddle = styled(motion.g)`
  transform-box: fill-box;
  transform-origin: 60% 40%;
  animation: ${oilSpill} 30s infinite 5s linear;
  opacity: 0;
`;

const oilDrip = keyframes`
  0% {
    opacity: 0;
  }
  10% {
    opacity: 1;
    transform: scale(1) translateY(2px);
  }
  90% {
    opacity: 1;
  }
  95% {
    transform: scale(0.9) translateY(50px);
  }
  98% {
    opacity: 0;
    transform: scale(0.9) translateY(50px);
  }
`;

const OildDrip = styled(motion.g)`
  transform-box: fill-box;
  transform-origin: 50% 50%;
  animation: ${oilDrip} 6s infinite 5s linear;
  opacity: 0;
`;

const ploom = keyframes`
0% {
  opacity: 0;
  transform: translateY(10px);
}
10% {
  opacity: 1;
  transform: translateY(-20px);
}
100% {
  opacity: 0;
  transform: translateY(-40px);
}
`;

const Smoke = styled('g')`
  > * {
    opacity: 0;
    animation: ${ploom} 3s infinite;
  }

  ${new Array(3).fill(0).map(
    (_, i) => `
  > :nth-child(${i + 1}) {
    animation-delay: ${4 + i * 0.2}s
  }
  `
  )}
`;

function NoProjectEmptyState() {
  return (
    <svg
      width="683"
      height="600"
      viewBox="0 0 683 600"
      fill="none"
      xmlns="http://www.w3.org/2000/svg"
    >
      <Background>
        <path d="M425.89 15.49v118.33h128c.38 0 0-118 0-118l-128-.33z" fill="#E7E1EC" />
        <path
          d="M296.03 495.11H24.41V342.56h71.07v11.55h32.37v16.74h63.63v-58.06h152.37V167.68h191.44v106h-62v70.33l-178 .56.74 150.54z"
          fill="#E7E1EC"
        />
        <path
          d="M519.22 129.67a4.83 4.83 0 110-9.65 4.83 4.83 0 010 9.65zm0-8.65a3.83 3.83 0 100 7.66 3.83 3.83 0 000-7.66z"
          fill="#C7BFD0"
        />
        <path
          d="M354.22 223.11a4.83 4.83 0 11-.02-9.66 4.83 4.83 0 01.02 9.66zm0-8.65a3.83 3.83 0 103.54 2.35 3.83 3.83 0 00-3.54-2.4v.05z"
          fill="#C7BFD0"
        />
        <path
          d="M375.99 222.69a4.83 4.83 0 11-.02-9.66 4.83 4.83 0 01.02 9.66zm0-8.65a3.83 3.83 0 10-.02 7.67 3.83 3.83 0 00.02-7.67z"
          fill="#C7BFD0"
        />
        <path
          d="M62.69 356.27a4.83 4.83 0 11-.02-9.67 4.83 4.83 0 01.02 9.67zm0-8.65a3.83 3.83 0 10-.02 7.66 3.83 3.83 0 00.02-7.66z"
          fill="#C7BFD0"
        />
        <path
          d="M63.06 389.76a4.83 4.83 0 11-.02-9.67 4.83 4.83 0 01.02 9.67zm0-8.65a3.83 3.83 0 10-.02 7.66 3.83 3.83 0 00.02-7.66z"
          fill="#C7BFD0"
        />
        <path
          d="M154.59 435.11a4.83 4.83 0 110-9.66 4.83 4.83 0 010 9.66zm0-8.65a3.84 3.84 0 103.83 3.83 3.83 3.83 0 00-3.83-3.79v-.04z"
          fill="#C7BFD0"
        />
        <path
          d="M180.82 434.83a4.83 4.83 0 110-9.65 4.83 4.83 0 010 9.65zm0-8.65a3.83 3.83 0 100 7.66 3.83 3.83 0 000-7.66z"
          fill="#C7BFD0"
        />
        <path
          d="M249.66 330.46a4.83 4.83 0 110-9.65 4.83 4.83 0 010 9.65zm0-8.65a3.83 3.83 0 100 7.66 3.83 3.83 0 000-7.66z"
          fill="#C7BFD0"
        />
        <path
          d="M182.31 479.11a4.83 4.83 0 110-9.65 4.83 4.83 0 010 9.65zm0-8.65a3.83 3.83 0 100 7.66 3.83 3.83 0 000-7.66z"
          fill="#C7BFD0"
        />
        <path
          d="M42.78 423.67a4.83 4.83 0 11-.02-9.67 4.83 4.83 0 01.02 9.67zm0-8.66a3.83 3.83 0 10-.02 7.65 3.83 3.83 0 00.02-7.65z"
          fill="#C7BFD0"
        />
        <path
          d="M426.59 315.11a4.83 4.83 0 110-9.65 4.83 4.83 0 010 9.65zm0-8.65a3.83 3.83 0 100 7.66 3.83 3.83 0 000-7.66z"
          fill="#C7BFD0"
        />
        <path
          d="M427.71 336.88a4.83 4.83 0 11-.02-9.67 4.83 4.83 0 01.02 9.67zm0-8.66a3.83 3.83 0 10-.02 7.66 3.83 3.83 0 00.02-7.66z"
          fill="#C7BFD0"
        />
        <path
          d="M376.54 197.2a4.83 4.83 0 110-9.66 4.83 4.83 0 010 9.66zm0-8.65a3.84 3.84 0 100 7.67 3.84 3.84 0 000-7.67z"
          fill="#C7BFD0"
        />
        <path
          d="M519.22 83.62a4.83 4.83 0 110-9.66 4.83 4.83 0 010 9.66zm0-8.65a3.83 3.83 0 100 7.66 3.83 3.83 0 000-7.66z"
          fill="#C7BFD0"
        />
        <path
          d="M486.59 83.62a4.83 4.83 0 110-9.66 4.83 4.83 0 010 9.66zm0-8.65a3.83 3.83 0 100 7.66 3.83 3.83 0 000-7.66z"
          fill="#C7BFD0"
        />
        <path
          d="M456.22 83.62a4.83 4.83 0 110-9.66 4.83 4.83 0 010 9.66zm0-8.65a3.83 3.83 0 100 7.66 3.83 3.83 0 000-7.66z"
          fill="#C7BFD0"
        />
        <path
          d="M435.94 335.34a.5.5 0 01-.5-.49l-.56-42.42a.5.5 0 01.5-.51.5.5 0 01.35.15c.1.09.15.22.15.35l.56 42.41a.5.5 0 01-.49.51h-.01z"
          fill="#C7BFD0"
        />
        <path d="M71.42 397.33v-54.77h-1v54.71l1 .06z" fill="#C7BFD0" />
        <path
          d="M215.86 388.57h-26.12v-17.73h-1v17.85a.5.5 0 000 .76v48.24h-57.79v-66.85h-1v40.13a.48.48 0 00-.24-.07l-21.77.07v1l21.76-.07c.09 0 .17-.03.24-.07v26.36c0 .13.05.26.15.35.09.1.22.15.35.15h42.29v56.42h1v-56.42h15.49a.5.5 0 00.35-.15.5.5 0 00.15-.35v-48.62h26.24a7.99 7.99 0 01-.1-1z"
          fill="#C7BFD0"
        />
        <path
          d="M238.42 312.79v75.78h-2.14c.06.34.12.67.16 1h2.48a.5.5 0 00.35-.15.5.5 0 00.15-.35v-76.28h-1z"
          fill="#C7BFD0"
        />
        <path
          d="M383.72 167.68v56.9l-39.87-.1v1l78.88.19a.5.5 0 00.35-.15.5.5 0 000-.7.5.5 0 00-.35-.15l-38-.09v-56.9h-1.01z"
          fill="#C7BFD0"
        />
        <path
          d="M527.42 68.33a.53.53 0 00-.15-.36.56.56 0 00-.36-.14l-99.63.84a.5.5 0 100 1l99.13-.84.26 65h1l-.25-65.5z"
          fill="#C7BFD0"
        />
      </Background>
      <OildDrip>
        <path
          d="M592.5 451.5C592.5 452.24 588.47 467.96 587.94 472.24C587.41 476.52 588.69 481.83 596.5 481.54C601.5 481.35 602.5 475.77 601.5 471.68C600.5 467.59 592.5 451.5 592.5 451.5Z"
          fill="#2F1D4A"
        />
      </OildDrip>
      <OilPuddle>
        <path
          id="oil-pool"
          d="M624.59 525.44c18.42-3.07 49.29-7.66 39.35-15.07-9.59-7.13-29.88-11.14-51.3-13.36 2.75-5.16 4.82-11 1.16-12.5-5.53-2.24-9 6.22-10.65 11.62-2.28-.18-4.55-.34-6.81-.49-.2-1.32-.54-2.62-1-3.87-1.3-3.53-6.14-4.09-7.25-.37-.3 1.24-.3 2.53.05 3.76h-.49c-.61-1.1-1.32-2.35-2.17-3.74-3.72-6.14-10.6-4.47-11.16 1.11-.06.71.03 1.43.26 2.11-19.55-.57-35.24.13-35.24.13s-23.46-1.63-36.84 2.24c-13.38 3.87-22.48 7.52-22.48 7.52.56.28-23.25 7.73-19.25 18.42 2.2 5.9 26 7 49.11 5.86 23.11-1.14 40.75-.28 42.7 2.24 1.95 2.52-19.25 7-21.21 14.23-1.96 7.23 52.75 13.39 85.12 11.44 32.37-1.95 44.84-8.85 34.88-17.3-9.15-7.84-45.15-10.91-26.78-13.98z"
          fill="#2F1D4A"
        />
        <path
          d="M578.45 518.11c-.6 0-14.71-.6-20-4.18a2.65 2.65 0 01-1.47-2.56c.45-3 8-5.5 8.86-5.77a.48.48 0 01.38.03.49.49 0 01.24.3.5.5 0 01-.03.38.5.5 0 01-.29.24c-3 .95-7.9 3.13-8.17 5 0 .2-.12.8 1 1.58 5 3.42 19.32 4 19.46 4a.5.5 0 01.35.15.5.5 0 010 .7.5.5 0 01-.35.15l.02-.02z"
          fill="white"
        />
        <path
          d="M613.02 518.71h-1.28a.5.5 0 01-.35-.16.5.5 0 01-.14-.36.53.53 0 01.52-.48c.16 0 15.92.48 18.89-5a1.62 1.62 0 00.08-1.55c-1.2-2.63-8.55-4.76-11.28-5.35a.5.5 0 01-.4-.6.5.5 0 01.61-.4c.43.1 10.33 2.29 12 5.92a2.61 2.61 0 01-.11 2.44c-2.79 5.1-14.58 5.54-18.54 5.54z"
          fill="white"
        />
        <path
          d="M596.72 515.39h-3.77c-8.85-.26-22.34-1.77-23.26-4.85-.15-.48-.09-1.23 1-2 2.94-2.06 10.52-2.76 14.06-3a32.26 32.26 0 01-4.41-2.92 22.76 22.76 0 01-4.77-5.53.51.51 0 01.36-.75h.2a.5.5 0 01.3.24 22.15 22.15 0 004.54 5.26 34.26 34.26 0 005.85 3.66.5.5 0 01-.2.95c-.11 0-11.8.4-15.35 2.89-.35.24-.75.6-.65.91.5 1.69 9.6 3.76 22.33 4.13 12.73.37 26.58-1.08 28.54-3a.38.38 0 00.15-.24c-.1-.85-5.79-1.83-12.17-2.11a.5.5 0 01.04-1c11.43.5 13.13 2.16 13.13 3.11a1.34 1.34 0 01-.45 1c-2.32 2.22-15.37 3.25-25.47 3.25z"
          fill="white"
        />
        <path
          d="M600.03 509.94h-.13a.5.5 0 01-.35-.61s1.15-4.13-.35-6.19a3.04 3.04 0 00-2.53-1.18 3.72 3.72 0 00-3 1.11c-1.63 1.75-1.3 5-1.3 5a.5.5 0 01-.1.37.5.5 0 01-.9-.26c0-.16-.38-3.75 1.56-5.83a4.77 4.77 0 013.79-1.43 4.06 4.06 0 013.31 1.59c1.79 2.46.56 6.87.5 7.05a.5.5 0 01-.5.38z"
          fill="white"
        />
        <path
          d="M605.22 504.92a.5.5 0 01-.46-.31.5.5 0 01.11-.54s3.9-3.91 5-5.18a.48.48 0 01.34-.18.5.5 0 01.53.46.52.52 0 01-.11.37c-1.12 1.3-4.89 5.07-5 5.23a.5.5 0 01-.41.15z"
          fill="white"
        />
      </OilPuddle>
      <MainWindows>
        <path
          d="M59.76 411.11c-16.58 0-30.25 0-35.35-.08v1c4.55.08 15.16.1 28.07.1h7.49l-.21-1.02z"
          fill="#C7BFD0"
        />
        <path
          d="M199.29 540.51l4.09 14.52 36.47 10.41s1.11.75 3.35-.37 38.32-22.7 38.32-22.7l1.86-18.6-42 25.3-42.09-8.56z"
          fill="#B39ED3"
        />
        <path
          d="M235.94 390.01l-17.59 1.98.66 4.3-4.63-.34.67 14.55 3.63.66 1 4.3 17.19.99-.93-26.44z"
          fill="#B39ED3"
        />
        <path
          d="M381.94 555.58c.58-.12 2.23-3.34 2.37-6.27.14-2.93-2.65-9.07-2.65-9.07l-4.6.83c-.56.58-.95 1.3-1.12 2.1-.14 1.11-1 2.23-4.19 2.93-3.19.7-7.81.14-10.6-.56-2.79-.7-16.33 1.11-23.72 5.72-7.39 4.61-14.79 13.85-14.79 15.63 0 1.78.14 1.81 1.67.14a73.22 73.22 0 0112.7-9.77 29.81 29.81 0 018.51-2.79s-7 3.35-10.6 9.07c-3.6 5.72-6.7 10.32-5.72 12 .98 1.68.83-1 5.3-5.44s12.14-8.8 14.79-9.91c2.65-1.11 7.12-2.51 7.12-2.51l8.93-2.79a4.9 4.9 0 014-3.07c2.93-.14 6.56 4.18 6.56 4.18 2.02.01 4.04-.13 6.04-.42z"
          fill="#B39ED3"
        />
        <path
          d="M444.13 557.17l.83-2.14c-.2-.46-.45-.9-.74-1.31-.28-.21-.6-.37-.93-.46-.21-2.88-.15-5.78.19-8.65.55-5 1.48-7 1.48-7s2.33 5.68 2.79 7.26c.26.68.39 1.4.38 2.14.57-.2 1.2-.2 1.76 0 .5.27 1.04.48 1.59.65l3.53-10.51s2.79 4.37 2.79 7.07-2.88 9.2-2.88 9.2l-2.33.84.37 2.79-8.83.1"
          fill="#B39ED3"
        />
        <path
          d="M397.61 596.51l-39.81-43.34a2.88 2.88 0 01.37-3.17 2.33 2.33 0 012.59-.53c.28.12.54.3.76.53l44.84 38.89a5.2 5.2 0 01-1.86 6.69c-4.53 3.46-6.89.93-6.89.93z"
          fill="#F58452"
        />
        <path
          d="M443.29 553.26s-6.51 8.85-8.07 14.74c-1.56 5.89.14 14.79.14 14.79s.84 1.26 3.35 1.26c2.51 0 3.35-1.26 3.35-1.26s-2-9.21-.56-16.6c1.44-7.39 3.91-10.47 3.91-10.47s.32-2.55-2.14-2.46"
          fill="#F58452"
        />
        <path
          d="M453.1 553.91s10.61 12.7 12.28 19.39c1.67 6.69 1.4 9.91 1.4 9.91 1.23.65 2.63.9 4 .7 2.52-.28 2.79-1.26 2.79-1.26s-1.25-12.28-6.27-19a53.8 53.8 0 00-11.45-11 2.08 2.08 0 00-2.36.52c-.2.21-.34.47-.43.74"
          fill="#F58452"
        />
        <path
          d="M544.5 403.21a988.2 988.2 0 0011.44-5.44l-.14-3.49s34.33.84 34.74.7c.41-.14 6 .84 8-4.74s11.44-41.59 11.44-41.59a49.59 49.59 0 00-9.49 4.33c-3.04 1.9-5.9 4.1-8.51 6.56l-7.12 23.16-31.53 1.12.28-3.21-8.23.7-.84 21.9"
          fill="#B39ED3"
        />
        <path
          d="M543.94 412.42l50.23 2s4.33-.28 4.47 4.18c.14 4.46-.14 22.61-.14 22.61l5.58.14-2 13.39-26.19-.63-5.58-15 8.93.14-.56-8.37s.42-1.26-.83-1.26l-34.89-.14 1-17"
          fill="#B39ED3"
        />
        <path
          d="M291.94 506.75l-3.63-46.05h-47.16l-7.26-116.37s-.83-7.26 6.42-7.54c7.25-.28 300.56-7 300.56-7s7.81-1.12 7.54 8.65c-.27 9.77-9.08 150.11-8.84 154.6.28 5.3-1.49 10.89-10.42 10.89-10.93.03-237.21 2.82-237.21 2.82z"
          fill="white"
        />
        <path
          d="M419.75 400.61c.56-.37 27.35-4.65 27.35-4.65s-.74 97.48-1.3 97.3l-24.58-7.82-1.47-84.83z"
          fill="#B39ED3"
        />
        <path
          d="M454.22 430.75l6.7-.19s2.05-.56 2.05 3.16-.56 30.52-.56 30.52-1.86 1.86-1.86-.38-1.54-24.75-1.54-24.75l-5.4-.19.61-8.17z"
          fill="#B39ED3"
        />
        <path d="M75.76 443.4l3.72 17.49 21.95-1.86v-17.49l-24.93 4.37" fill="#B39ED3" />
        <path
          d="M107.22 467.47l-39.25 1.09-4.07-32.37a.5.5 0 00-.55-.44.5.5 0 00-.45.55l4.17 32.81a.5.5 0 00.5.44l40.19-1.11a.5.5 0 00.48-.5l.07-12.4c0-1-1-.95-1-.16l-.09 12.09z"
          fill="#2F1D4A"
        />
        <path
          d="M78.01 397.78c.72-.11.79-1-.17-1l-19.22.72a.53.53 0 00-.36.18.51.51 0 00-.12.39l4.27 33.94c.17.89 1.15.71 1-.11l-4.19-33.42 18.79-.7z"
          fill="#2F1D4A"
        />
        <path
          d="M108.47 395.78a.52.52 0 00-.36-.14l-24.11.91c-.73.14-.84 1.05 0 1l23.59-.89-.11 21.78c0 .78 1.08.68 1-.2l.12-22.09a.52.52 0 00-.13-.37z"
          fill="#2F1D4A"
        />
        <path
          d="M107.49 422.2l-.14 26.91c.06.92 1 .89 1-.06l.14-26.81c0-.89-1.01-.99-1-.04z"
          fill="#2F1D4A"
        />
        <path d="M73.01 408.1l3.91-3.77.84 11.16-3.63 1.82-1.12-9.21z" fill="#2F1D4A" />
        <path d="M94.36 407.54l-4.04-3.91.27 11.58 3.49 1.68.28-9.35z" fill="#2F1D4A" />
        <path
          d="M78.73 428.05s.39-7 5.72-7.4c5.33-.4 7.12 7 7.12 7l-12.84.4z"
          fill="#2F1D4A"
        />
        <path
          d="M75.1 459.39a.5.5 0 01-.48-.38c-4.22-16.89-4.09-17.28-4-17.44a.5.5 0 01.44-.34l28.88-2.24a.52.52 0 01.5.3.5.5 0 01.04.19c0 .69.28 16.9.28 17.45a.5.5 0 01-.46.5l-25.12 1.95-.08.01zm-3.48-17.21c.39 2.05 2.41 10.35 3.87 16.18l24.22-1.89c0-2.47-.22-13.84-.26-16.44l-27.83 2.15z"
          fill="#2F1D4A"
        />
        <path
          d="M76.5 446.41a.47.47 0 01-.3-.1l-3.91-2.93a.5.5 0 01-.1-.7.5.5 0 01.7-.1l3.76 2.81 19.41-1.77 3.35-4.16a.5.5 0 01.34-.22.5.5 0 01.39.1.5.5 0 01.16.56.49.49 0 01-.11.18l-3.49 4.33a.5.5 0 01-.34.18l-19.82 1.82h-.04z"
          fill="#2F1D4A"
        />
        <path
          d="M100.08 457.29a.49.49 0 01-.32-.12l-2.94-2.51a.51.51 0 01-.17-.33l-1-10.19a.5.5 0 111-.09l1 10 2.78 2.38a.5.5 0 01.05.71.52.52 0 01-.4.15z"
          fill="#2F1D4A"
        />
        <path
          d="M217.71 406.19l-5.95-1.49-1.3-11.9 5.95-1.31"
          stroke="#2F1D4A"
          strokeLinecap="round"
          strokeLinejoin="round"
        />
        <path
          d="M236.87 412.52l-18.97-3.54-1.68-21.58 18.42-4.84"
          stroke="#2F1D4A"
          strokeLinecap="round"
          strokeLinejoin="round"
        />
        <path
          d="M273.4 490.16a3 3 0 01-1.51-.37c-1.29-.69-2.23-2.39-2.95-5.34-.4-1.67-.73-3.36-1-5.06-.51-2.82-.95-5.26-1.81-5.65-.1 0-.39-.18-1.08.23-3.16 1.86-10.23 5.95-10.23 5.95l-.51-.86s7.07-4.09 10.23-5.95a2.11 2.11 0 012-.28c1.34.61 1.75 2.91 2.38 6.39.27 1.5.58 3.22 1 5 .64 2.62 1.44 4.16 2.45 4.7 1.01.54 2.23.1 3.66-.41l.5-.18c3.52-1.23 7-6.09 7-6.14a.5.5 0 01.9.2.5.5 0 01-.08.38c-.15.21-3.67 5.17-7.5 6.5l-.49.18c-.94.4-1.94.64-2.96.71z"
          fill="#2F1D4A"
        />
        <path
          d="M271.54 503.04c-.16 0-.31-.02-.46-.07-.83-.25-1.27-1.15-1.83-2.28a14.37 14.37 0 00-2.24-3.56c-2.22-2.5-10 1.24-12.77 2.88a.5.5 0 01-.55-.02.5.5 0 01.04-.84c1.11-.65 10.87-6.24 14-2.69a16 16 0 012.39 3.78c.45.92.81 1.65 1.22 1.78.36.04.72-.05 1-.27.75-.44 1.48-.92 2.18-1.44 1.75-1.42 3.8-2.4 6-2.89 3.83-.77 5.26.16 5.42.27a.5.5 0 01.11.7.5.5 0 01-.7.11s-1.24-.78-4.63-.1a13.48 13.48 0 00-5.59 2.72c-.73.54-1.48 1.04-2.26 1.5-.4.26-.86.4-1.33.42z"
          fill="#2F1D4A"
        />
        <path
          d="M540.03 329.82s-293.3 6.69-300.55 7c-7.25.31-6.42 7.54-6.42 7.54l2.09 33.54c26.85-.48 274.73-4.85 310.68-5.47 1-17.81 1.66-31.17 1.74-33.93.28-9.8-7.54-8.68-7.54-8.68z"
          fill="#2F1D4A"
        />
        <path
          d="M419.48 480.52l-69.49 1.95-7.81-84.28 76.18-3.07 1.12 85.4z"
          fill="#2F1D4A"
        />
        <path
          d="M418.45 395.03c.56 0 24.37-3 24.37-3l-.37 96-23.07-7.63"
          stroke="#2F1D4A"
          strokeLinecap="round"
          strokeLinejoin="round"
        />
        <path
          d="M279.53 523.11a.29.29 0 00-.13 0l-18.58-4c-1.07-.38-1.62.41-.67.88l17.71 3.83c-11.73 6.34-38.37 20.68-40.46 21.6-1.65-.37-17-3.82-28.58-6.63-.74-.2-1 .74-.08 1 11.17 2.72 25.72 6 28.23 6.55.18 1.31.84 5.43 1.46 9.23a.51.51 0 000 .24l.95 5.78-11.14-2.69c-.7-.16-.93.84.07 1l11.4 2.76c.08.06.19.1.29.1h.22a.5.5 0 00.24-.06l37.4-21a.47.47 0 00.25-.38l1.86-17.67a.5.5 0 00-.44-.54zm-39.1 38.5l-.94-5.73 28.24-14.21.61 4.25-27.91 15.69zm28.84-16.22l-.65-4.55a.52.52 0 00-.26-.38.52.52 0 00-.46 0l-28.58 14.36-.57-3.52 17.13-8.48a.5.5 0 00-.03-.95.5.5 0 00-.41.06l-16.85 8.33c-.22-1.35-.43-2.7-.63-4.06 1.38-.65 6.53-3.3 26.61-14.11l1 6.09a.48.48 0 00.27.37.5.5 0 00.46-.02l7.33-4.08.67 8.09-5.03 2.85zm7.88-4.42l-1.87 1-.7-8.41a.54.54 0 00-.26-.4.51.51 0 00-.48 0l-7.38 4.12-1-5.72 13.39-7.22-1.7 16.63z"
          fill="#2F1D4A"
        />
        <path
          d="M220.9 557.11c-9.73-2.38-19.69-4.86-20.87-5.31a3.23 3.23 0 01-2.3-2.45l-3.72-14.06c.6.44 1.24.8 1.93 1.07 1 .4 3.49 1.1 6.75 1.93.61.23 1-.78.16-1-2.2-.52-4.4-1.14-6.54-1.87-1.83-.73-2.86-1.76-2.89-2.88 0-1.32 1.34-2.76 3.66-3.83l3.16-1.52c.82-.42.31-1.21-.88-.69s-2.22 1.08-2.7 1.3c-2.74 1.27-4.28 3-4.23 4.77 0 .19.02.38.07.56a.53.53 0 000 .28l4.27 16.1a4.14 4.14 0 002.92 3.21c1.24.48 11.49 3 21.36 5.44.61.1.75-.81-.15-1.05z"
          fill="#2F1D4A"
        />
        <path
          d="M214.32 519.11l-8.38 4.15c-.7.52-.05 1.26 1 .63l8.49-4.2c.84-.43.28-1.41-1.11-.58z"
          fill="#2F1D4A"
        />
        <path
          d="M228.6 512.11a.5.5 0 00-.32 0l-8.09 4c-.9.57-.11 1.31 1 .62l7.36-3.67 25.59 5.53c.81.41 2.07-.47.67-.87l-26.21-5.61z"
          fill="#2F1D4A"
        />
        <path
          d="M256.69 544.43c.98 0 1.77-1.04 1.77-2.33s-.8-2.33-1.77-2.33c-.98 0-1.77 1.04-1.77 2.33s.8 2.33 1.77 2.33z"
          fill="#F48352"
        />
        <path
          d="M442.36 488.05l8.93-.56 3.35-95.16-11.72-.28"
          stroke="#2F1D4A"
          strokeLinecap="round"
          strokeLinejoin="round"
        />
        <path
          d="M453.8 426.65h8.09s2.79-.55 2.52 2.52c-.27 3.07-1.53 28.39-1.61 29.44-.14 1.74-1.81 2.3-2-.42-.33-4.21-1-20.58-1-20.58s.14-2.44-2.09-2.86a30.6 30.6 0 00-4.47 0"
          stroke="#2F1D4A"
          strokeLinecap="round"
          strokeLinejoin="round"
        />
        <path
          d="M324.22 562.86c1.84-3 3.94-5.81 6.29-8.42-.27-.22-.54-.46-.79-.7a54.84 54.84 0 00-6.15 8.23c.23.28.45.58.65.89z"
          fill="#2F1D4A"
        />
        <path
          d="M340.53 546.55a59.71 59.71 0 0120.45-5.34c.74.59 3.93 3 7 3 3.71 0 3.94-.68 4-.88l1.76-4.66a12.78 12.78 0 012.86 6.42c.4 2.4.07 4.87-.94 7.09l-3-3.06a.59.59 0 00-.27-.14 10.58 10.58 0 00-3.36 0c-.7.18-.32 1.19.6.92.8-.1 1.62-.1 2.43 0l3.28 3.28a.51.51 0 00.5.44h.06l4.32-.51h.13c.14-.06 3.35-1.52 2.91-7.94-.38-5.53-3-8-3.14-8.14a.47.47 0 00-.37-.14l-6.14.37h-.05l-.14.07h-.05a.4.4 0 00-.1.15l-2 5.28c-1 .33-2.06.45-3.11.35-3.12 0-6.52-2.83-6.56-2.86a.49.49 0 00-.34-.12 60.25 60.25 0 00-21 5.44 31.62 31.62 0 00-8.18 5.85l.76.71a29.9 29.9 0 017.69-5.58zm39-8.69a12.25 12.25 0 012.68 7.34c.37 5.28-1.87 6.72-2.25 6.92l-3.34.44a13.23 13.23 0 001-7.66 13.78 13.78 0 00-2.93-6.74l4.84-.3z"
          fill="#2F1D4A"
        />
        <path
          d="M367.22 568.02c-.59-.54-1.18 0-.79.61l13.07 15.24c.46.53 1.22-.07.91-.48l-13.19-15.37z"
          fill="#2F1D4A"
        />
        <path
          d="M355.09 549.31a3.3 3.3 0 013.49.13l21.85 20 .2-.09.43-.23.14-.08.13-.08-16.63-15.23a4.72 4.72 0 012-2.72c.82-.51.2-1.28-.57-.83a6 6 0 00-2.29 2.81l-4.62-4.32a4.28 4.28 0 00-4.65-.2c-1.88 1.19-1.69 3.57-1.33 4.67.02.06.06.12.1.16l1.27 1.49a51.32 51.32 0 00-13.06 6 31.37 31.37 0 00-11.79 12.84l-.29.55c-.08.14-.32.44-.44.44-.18 0-.44-.24-.62-.47.77-2.78 1.8-5.47 3.07-8.06 3.43-6.87 11.84-12.78 11.93-12.84a.5.5 0 00.18-.29.5.5 0 00-.64-.58 73.38 73.38 0 00-10.13 4.87c-4.19 2.51-7.52 6.55-8.95 8.28l-.48.57c-.07.09-.15.16-.24.23-.19-.24-.3-.52-.35-.82l.07-.16h-.36c-.2.02-.4-.02-.57-.1a1.4 1.4 0 00-.1.36c.06.35.31 1.5 1.09 1.72a1.24 1.24 0 001.27-.55c.14-.15.3-.35.49-.58a36.54 36.54 0 018.69-8.06 63.39 63.39 0 016.51-3.34c-2.85 2.39-7 6.39-9.26 10.87a47.55 47.55 0 00-3.2 8.48c-.03.13 0 .27.06.38.07.11.7 1.12 1.59 1.12a1.57 1.57 0 001.3-1l.31-.57a30.42 30.42 0 0111.42-12.46c7.82-4.72 13-5.88 13.06-5.89a.48.48 0 00.19-.09l8.46 9.88c.45.56 1.29 0 .88-.51l-10.49-12.25c-.18-.48-.64-2.48.88-3.45z"
          fill="#2F1D4A"
        />
        <path
          d="M404.6 590.99a4.73 4.73 0 00-.93-1.49.43.43 0 00-.14-.24l-19.07-17.47-.87.56 16.93 15.51a9.3 9.3 0 00-9.32 3.79c-.65.93-1 2.05-1 3.19l-7.4-8.73c-.62-.78-1.21-.11-.77.64l9.25 10.79h.06c.73.82 1.68 1.4 2.73 1.68.7.2 1.44.3 2.17.3 1.14 0 2.26-.22 3.33-.62a8.9 8.9 0 004.35-3.37 5.13 5.13 0 00.68-4.54zm-1.52 4.12a8.35 8.35 0 01-8.73 3.27 4.12 4.12 0 01-2.89-2.42 4.17 4.17 0 01.58-3.73 7.88 7.88 0 013.87-3 8.48 8.48 0 013-.56c.64 0 1.27.09 1.89.26a3.85 3.85 0 012.31 6.15l-.03.03z"
          fill="#2F1D4A"
        />
        <path
          d="M401.34 476.89l-1.82 3.62 9.91-.27-2.21-3.63-2.15.1c.64-5.21-.12-9.29-2.27-12.1-2-2.64-5.32-4.22-9.76-4.69-6.91-.72-8.15-6.85-8.33-10l6.46-.62-.38-6.17c3.72-.6 9.56-2.11 13.43-5.89a16.99 16.99 0 004.56-14 13.25 13.25 0 00-6.76-10.1c-6.18-3.42-6.72-7.7-6.5-9.91l6.53-.4-.14-6.69-50.51 2.23c0 .42 2.23 7.39 2.23 7.39l13.73-.83c0 1.72-.49 4.33-3.14 5.24-3.83 1.32-6.28 3.08-7.41 5.34-6.34.42-12.46.86-12.66.86 0 0 3.9 43.67 3.9 44.23l6.25-.66c-.86 3-2.64 10.41-.51 13.72a3.56 3.56 0 002.72 1.67c3.8.42 5.51-1.45 7-3.1 1.15-1.27 2.25-2.47 4.23-2.62 4.28-.35 5.53 5.94 5.81 7.9l-2.49.11-1.84 3.59 9.91-.28-2.23-3.62-2.36.11c-.28-2.07-1.62-9.21-6.89-8.85-2.38.18-3.66 1.59-4.9 2.94-1.47 1.62-2.87 3.14-6.17 2.79a2.6 2.6 0 01-2-1.22c-2-3.08 0-10.71.75-13.3l5.51-.58c.79 2 3.27 5.85 10.75 5.77 9.45-.15 12.94.91 15.49 4.66a11.84 11.84 0 011.9 7.54l-2.88.14-1.82 3.62 9.91-.28-2.23-3.62-2 .09c.23-2.84-.5-5.68-2.08-8.05-2.79-4.1-6.45-5.25-16.33-5.1h-.3c-6.45 0-8.68-3.09-9.43-4.88l11.13-1.18-.36-6.88 11.05-1.06c.19 3.48 1.57 10.15 9.21 10.95 4.16.43 7.22 1.88 9.07 4.3 2 2.62 2.7 6.51 2.06 11.54l-2.64.13zm.17-62.91a12.23 12.23 0 016.26 9.35 16.13 16.13 0 01-4.27 13.15c-3.61 3.52-9.19 5-12.79 5.59l-.37-6.1c3.32-.72 8.72-2.78 9.81-8.53.77-4 .25-7.13-1.59-9.43-2.35-2.93-6.78-4.47-13.53-4.69-3.93-.13-6.66-1.23-8.12-3.27a7.78 7.78 0 01-1.09-5.67l18.7-1.13c-.18 2.54.54 7.15 6.99 10.73zm-30.59.81c.07-.2-6.35.17-12.92.6 1.13-1.77 3.29-3.2 6.52-4.31 3.23-1.11 3.78-4.26 3.8-6.25l6.47-.39a8.58 8.58 0 001.3 6.18c1.65 2.31 4.65 3.55 8.9 3.7 6.45.21 10.63 1.62 12.79 4.31 1.64 2.06 2.1 4.88 1.39 8.63-1 5.11-5.8 7-8.9 7.71l-.79-13.06-18.26.62c-.21-4.51-.34-7.62-.3-7.74z"
          fill="#B39ED3"
        />
        <path
          d="M419.48 480.52l-69.49 1.95-7.81-84.28 76.18-3.07 1.12 85.4z"
          stroke="#2F1D4A"
          strokeLinecap="round"
          strokeLinejoin="round"
        />
        <path
          d="M527.11 386.37c-1.53-1.59-7.81-7.79-15-14.87 5-4.64 9-8.28 10-9.22 3.16-3 6.33-8.37 1.12-13.77s-11-1.11-13.77 1.31c-.86.74-4.9 4.38-10.13 9.13-4.28-4.21-8.58-8.4-12.9-12.58-3.31-3.17-9.19-6.21-14.59-.41s-.57 11.65 2.14 14.46c.91.94 5.57 5.5 11.44 11.24-8.51 7.82-16.2 15-17.08 16.11-2.6 3.35-5.72 8-.93 12.65 5.21 5 10.61 2.05 14.89-1.67 1.66-1.45 8.46-7.65 16-14.56 8.34 8.11 15.85 15.4 16.93 16.42 3.73 3.55 9.89 6.69 14.51 1.37 4.98-5.78 1.54-11.3-2.63-15.61z"
          fill="white"
        />
        <path
          d="M531.58 388.41c-1.53-1.58-7.82-7.79-15-14.86 5-4.65 9-8.28 10-9.22 3.17-3 6.33-8.37 1.12-13.77s-11-1.12-13.77 1.3c-.85.75-4.89 4.39-10.12 9.14-6.4-6.26-11.68-11.42-12.9-12.58-3.32-3.18-9.19-6.22-14.6-.42s-.56 11.65 2.15 14.46c.9.95 5.56 5.51 11.44 11.24-8.51 7.82-16.21 15-17.08 16.12-2.61 3.35-5.73 8-.93 12.65 5.21 5 10.6 2 14.88-1.68 1.66-1.44 8.47-7.65 16-14.55 5.63 5.48 11.27 10.95 16.93 16.41 3.73 3.56 9.9 6.7 14.51 1.38 5.01-5.78 1.53-11.31-2.63-15.62z"
          fill="#E1557A"
        />
        <path
          d="M526.91 386.02c-1.52-1.57-7.61-7.59-14.65-14.51 4.94-4.54 8.73-8 9.6-8.86 1.48-1.39 4-4.25 4.05-7.85a9.22 9.22 0 00-2.91-6.63c-3.93-4.07-8.79-3.64-14.46 1.27-.65.57-4.59 4.11-9.78 8.83-4.2-4.07-8.38-8.15-12.54-12.26-1.54-1.48-4.71-3.92-8.48-3.83a9.7 9.7 0 00-6.83 3.44c-4.06 4.35-3.33 9.45 2.15 15.14.91 1 5.39 5.33 11.08 10.88-8.35 7.68-15.84 14.65-16.75 15.82-2 2.63-6.3 8.1-.88 13.32a8.9 8.9 0 006.29 2.78c4.16 0 7.75-3.12 9.27-4.44 1.52-1.32 8.27-7.47 15.66-14.24 8.27 8 15.65 15.19 16.59 16.09 1.4 1.33 5 4.35 9.07 4.35h.38a8 8 0 005.79-3c6.18-7.21-.46-14.04-2.65-16.3zm-17.69-35.83c5.26-4.55 9.54-5 13.08-1.33a8.2 8.2 0 012.63 5.92c-.08 3.23-2.37 5.86-3.73 7.14-.87.82-4.68 4.34-9.63 8.89l-12.08-11.84c4.9-4.48 8.73-7.92 9.73-8.78zm1.61 21.3l-13.09 12-12.16-11.83c4.48-4.11 9.15-8.38 13.17-12l12.08 11.83zm-37.08-11.38c-5.12-5.31-5.82-9.82-2.13-13.77a8.72 8.72 0 016.12-3.12h.21c3.33 0 6.15 2.21 7.55 3.55 1.07 1 6.22 6 12.52 12.21l-13.18 12-11.09-10.87zm7.63 38.3c-5.73 5-10.24 5.52-14.21 1.69-4.4-4.24-1.8-8.41 1-12 .83-1.07 8.31-8 16.68-15.73L497 384.2c-7.38 6.72-13.96 12.73-15.62 14.17v.04zm47.39 3.29a7.1 7.1 0 01-5.08 2.66c-3.83.19-7.36-2.79-8.71-4.07-.94-.9-8.29-8-16.54-16.05l13.08-12c4.94 4.78 9.84 9.6 14.7 14.47 5.56 5.78 6.38 10.53 2.55 14.95v.04z"
          fill="#2F1D4A"
        />
        <path
          d="M540.4 463.86c-.9 17.14-1.49 29.35-1.42 30.63a8.1 8.1 0 01-1.87 6.24c-1.72 1.81-4.68 2.73-8.8 2.73-4.12 0-39.11.4-81 .89-.74 0-.79 1 .07 1 .86 0 76.87-.89 81-.89 4.41 0 7.61-1 9.52-3 1.58-1.66 2.3-4 2.14-7-.06-1.26.53-13.45 1.43-30.58-.04-1.12-1.05-1.16-1.07-.02z"
          fill="#2F1D4A"
        />
        <path
          d="M409.5 504.81c-.95 0-.76 1.13.12 1l26.76-.32c.71 0 .89-1-.13-1l-26.75.32z"
          fill="#2F1D4A"
        />
        <path
          d="M239.85 445.29l-.63-10.24c-.06-.86-1.18-.91-1 .09l.64 10.25c.1 1.17.99.89.99-.1z"
          fill="#2F1D4A"
        />
        <path
          d="M287.97 460.66a.49.49 0 00-.49-.46h-46.7l-.66-10.56c0-.8-1-.8-1 .15l.68 10.94a.5.5 0 00.5.47h6.63l1.93 5.25a.5.5 0 00.47.33l21.77-.56a.5.5 0 00.48-.41l.82-4.61h14.59l.29 3.59c.07 1 1.05.65 1-.11l-.31-4.02zm-17.29 4.57l-21 .54-1.68-4.57h23.4l-.72 4.03z"
          fill="#2F1D4A"
        />
        <path
          d="M568.45 392.32l8.6.07c0-.33-.05-.67-.08-1l-8.49-.07-.03 1z"
          fill="#2F1D4A"
        />
        <path
          d="M588.87 391.54l-8-.11v1l7.91.11h.78c1.94 0 7-.69 8.73-7.52l2.18-8.6-1-.08-2.14 8.43c-1.97 7.65-8.11 6.82-8.46 6.77z"
          fill="#2F1D4A"
        />
        <path
          d="M606.59 449.7l-.24 1-26.32-.25s-1.15-4.21-1.53-5.15c-.38-.94-1.2-.77-1 .24.2 1.01 1.72 5.57 1.72 5.57a.53.53 0 00.48.36l27.09.26a.49.49 0 00.48-.39l.4-1.69c.08-.81-.89-.72-1.08.05z"
          fill="#2F1D4A"
        />
        <path
          d="M610.56 436.45a.51.51 0 00-.39-.19h-5.45c0-1.43 0-12.45-.07-13.24-.07-.79-.91-1-1 .12-.09 1.12.07 5.14.08 7.33l-20.38-1.36v-2.34a2 2 0 00-.71-1.66c-.13-.1-.27-.19-.42-.25l20.81-13.57c0 .18.08.36.1.56.23 1.69.38 4.54.48 7.72.09 1.14 1.11.82 1-.08-.05-2.6-.2-5.2-.49-7.78a6.44 6.44 0 00-6.52-5.95l-25.64-1c-1-.13-1 1-.07 1l7 .28c-1 3.25-5.18 16-5.87 18.25l-8.12-.47-3.68-18.5 7.06.27c.75 0 .89-.94 0-1l-23.7-.93.17-3.07v-.85l8.74-4.63a.49.49 0 00.27-.42l.07-2.23c1.28-.12 5.16-.16 10.16-.15l-.06-1c-4.6 0-8.45 0-10.07.16l.55-17.1 22-1c.48.06 2.86.23 3.67-3 .2-.8.59-2.13 1.05-3.67l-1-.26a78.8 78.8 0 00-1.06 3.69c-.65 2.58-2.37 2.3-2.57 2.26a.29.29 0 00-.13 0l-21.94 1 .11-3.14a.51.51 0 00-.27-.47l-7.69-4c.52-9.1.98-18.21 1.39-27.32.09-3.39-.75-5.91-2.51-7.49a7.4 7.4 0 00-5.54-1.67c-2.93.06-293.39 6.7-300.56 7a6.94 6.94 0 00-5.24 2.24 8.27 8.27 0 00-1.66 5.83l5.26 84.42c.07 1.36 1 1 1-.07l-5.27-84.44a7.47 7.47 0 011.43-5.09 6 6 0 014.51-1.89c7.17-.27 297.62-6.91 300.61-7a6.57 6.57 0 014.8 1.44c1.53 1.36 2.26 3.62 2.17 6.7-.07 2.41-.61 12.73-1.38 27.15a.4.4 0 00-.15.17.49.49 0 00.11.59l-1.85 34.18c-1 18.81-2.1 38.72-3 55.36 0 .93 1 .93 1-.11l1.73-32.22 10.57.6c.66 0 1-.87 0-1l-4.13-.23 3.35-17.93 7 .28 3.62 18.46-6.33-.37c-.87 0-.69 1 0 1l6.84.39h.14l15.9.9c.05.01.1.01.14 0a2 2 0 011.43.21 1.07 1.07 0 01.33.88c0 2.09.26 9.16.26 9.23.01.1.05.2.11.27h-7.24a.5.5 0 00-.4.2.53.53 0 00-.08.44l1.62 5.47c.38.8 1.13.61 1-.19l-1.46-4.92h33.42s-1.81 7.86-2.16 9.17c-.27 1 .78 1 1 .1l2.28-9.65a.5.5 0 00-.08-.42zm-63.94-69.56l7 3.62-.77 23.86-7.95 4.2c.63-11.52 1.23-22.4 1.72-31.68zm2.42 56l-5.4-.31c.33-6 .65-12 1-17.93l7.58.3-3.18 17.94zm31.74 1.67l-.08.08h-.29l-6.39-.36c1.94-6.1 3.9-12.18 5.88-18.27l17.66.7a5.34 5.34 0 015.15 3.52l-21.93 14.33zm22.94 11.7h-20.25c.07-.09.1-.2.1-.31l-.19-5.85 20.35 1.38-.01 4.78z"
          fill="#2F1D4A"
        />
        <path
          d="M582.64 362.02c.78-2.47 1.5-4.71 1.81-5.65.18.04.36.06.54.06 3 0 10.53-3.72 12.25-4.59a70.58 70.58 0 008.22-4.8c.71-.49 1.25-.91 1.69-1.28-1.06 4.22-3.88 15.5-6.31 25.14h1l6.68-26.65a.5.5 0 000-.21.8.8 0 00-.05-.63c-1-2-11.36 3.07-13.42 4.12a70.73 70.73 0 00-8.22 4.79c-2.29 1.6-3 2.48-3.11 3.05a.4.4 0 00-.1.18c-.08.22-1 3-2 6.12l1.02.35zm12.89-13.56c6.42-3.25 11-4.66 12-4.52-.49.92-4.34 3.75-10.75 7s-11 4.69-12 4.53c.49-.92 4.34-3.76 10.75-7.01z"
          fill="#2F1D4A"
        />
        <path
          d="M311.8 505.99l-20.23.25-2.86-36.27c-.08-.83-1-.79-1 .09l.54 6.8-4.51 2a.49.49 0 00-.3.5l.75 7.45c.01.1.05.19.11.27.06.07.15.13.24.16l4.63 1.37.28 3.49-4.09 2.41a.5.5 0 00-.24.46l.37 6.7a.5.5 0 00.31.43l4.58 1.87.23 2.83a.49.49 0 00.49.46l20.79-.26c.81-.01.91-.99-.09-1.01zm-26.65-19.63l-.68-6.74 3.86-1.7.76 9.61-3.94-1.17zm1.32 14.93l-.34-6.08 3.4-2 .76 9.65-3.82-1.57z"
          fill="#2F1D4A"
        />
        <path
          d="M326.09 506.82l75.35-.92c1 0 1-1 0-1l-75.36.92c-1-.01-.86 1.14.01 1z"
          fill="#2F1D4A"
        />
        <path
          d="M373.34 453.29a.49.49 0 01-.5-.47l-1.58-31a.48.48 0 01.13-.36.5.5 0 01.34-.16.48.48 0 01.37.12.47.47 0 01.15.35l1.58 31a.5.5 0 01-.03.2.5.5 0 01-.44.32h-.02z"
          fill="#2F1D4A"
        />
        <path
          d="M350.41 424.98a1.67 1.67 0 100-3.34 1.67 1.67 0 000 3.34z"
          fill="#EBB432"
        />
        <path
          d="M358.29 424.42a1.67 1.67 0 100-3.34 1.67 1.67 0 000 3.34z"
          fill="#F48352"
        />
        <path
          d="M350.13 424.83a1.8 1.8 0 01-1.27-3.07 1.8 1.8 0 111.27 3.07zm0-3.35a1.55 1.55 0 100 3.1 1.55 1.55 0 000-3.1z"
          fill="#2F1D4A"
        />
        <path
          d="M358.01 424.27a1.8 1.8 0 01-1.27-3.07 1.8 1.8 0 111.27 3.07zm0-3.35a1.55 1.55 0 100 3.1 1.55 1.55 0 000-3.1z"
          fill="#2F1D4A"
        />
        <path
          d="M439.03 583.31c-.86.55-1.88.83-2.9.8-2.13 0-3.61-1-3.61-1.87 0-.87 1.45-1.85 3.53-1.87a6.55 6.55 0 01-.45-1c-1.2.04-2.34.46-3.28 1.2-.07-3.62.24-7.23.9-10.78.28-1-.77-1.05-1-.26a51.79 51.79 0 00-.88 12.32c0 .12.07.24.16.32 0 1.61 2 2.87 4.61 2.87a5.43 5.43 0 004-1.41 5.14 5.14 0 01-1.08-.32z"
          fill="#2F1D4A"
        />
        <path
          d="M461.22 575.58c.15.76 1.09.52 1-.25a40.42 40.42 0 00-2.93-10.9c-.44-.83-1.39-.51-1 .23.39.74.57 1.31.83 2a39.68 39.68 0 012.1 8.92z"
          fill="#2F1D4A"
        />
        <path
          d="M469.88 579.7c0 .29.06.56.08.81a6.5 6.5 0 00-7.39 0v-1.6c0-.6-1.1-.57-1 .22.06 1 .06 2 0 3a.52.52 0 00.22.44c.27 1.44 2.16 2.52 4.55 2.52 2.39 0 4.24-1.06 4.55-2.47a.47.47 0 00.22-.39c.01-.67-.02-1.34-.09-2l-1.14-.53zm-3.61 4.41c-2.13 0-3.61-1-3.61-1.87 0-.87 1.48-1.88 3.61-1.88s3.61 1 3.61 1.88c0 .88-1.48 1.87-3.61 1.87z"
          fill="#2F1D4A"
        />
        <path
          d="M457.73 561.37c-.16-.9-2.83-4-3.79-4.93a.53.53 0 00-.24-.23c-.35-.32-.61-.55-.77-.67a1.62 1.62 0 01.26-1.25 1.75 1.75 0 011.5-.38l.44.28.37-.35c.13-.12.27-.23.42-.33l-.57-.37v-3.13c1.5-2 2.17-4.51 1.87-7-.06-.81-.18-1.62-.37-2.41-.17-.7-1.33-.59-.93.42.15.69.25 1.39.3 2.09a9.28 9.28 0 01-1.38 5.93v-.17a5.61 5.61 0 00-4.15-3.47l3.32-9a14 14 0 011 1.77c.38.78 1 .4.9-.46a9.14 9.14 0 00-1.65-2.68.5.5 0 00-.47-.16.5.5 0 00-.23.1.51.51 0 00-.15.22l-3.7 10h-.52c-.14-.67-.45-2.11-1-3.76a55.79 55.79 0 00-2.93-6.55.48.48 0 00-.42-.27.46.46 0 00-.44.22c-.08.13-2.38 4.28-2.43 6.07 0 1 .72 1 1 .06s0 0 .06 0a22.49 22.49 0 011.8-4.8c.93 1.8 1.75 3.66 2.44 5.57.4 1.31.74 2.65 1 4a.5.5 0 00.49.42s3.82-.09 5.15 3.07a2.14 2.14 0 01-.35 2.29 6.07 6.07 0 01-4.9 1.64c-3.31-.47-6.67-1.71-6.38-7.31.01-.6.06-1.2.16-1.78.12-.74-.9-.88-1 0-.07.58-.13 1.16-.16 1.78-.05.86 0 1.72.15 2.57a.53.53 0 00-.15.37l.16 4.18-.12.1c-1.13.88-4.13 3.21-7.15 10.32a21.96 21.96 0 00-1.14 3.23.52.52 0 101 .3c.18-.54.67-2.13 1.1-3.14 2.92-6.87 5.87-9.16 6.84-9.92l.24-.19c.53-.07 1.06.06 1.5.36a1.64 1.64 0 01.5 1.26c-.11.22-.52 1.08-1 2 .1.12.18.25.24.39.11.3.2.61.29.92.19-.49.39-.95.54-1.29 1.39.45 2.83.71 4.29.77h.69c1.41 0 2.81-.25 4.13-.76a43.3 43.3 0 013.27 4.23c.37.57 1.23.73 1.07-.17zm-9.15-4.36a15.1 15.1 0 01-3.91-.69l.4-.79a.48.48 0 00.07-.24 2.67 2.67 0 00-.92-2.18 2.9 2.9 0 00-1.87-.59l-.06-1.73c1.64 2.63 4.72 3.07 6.15 3.27.26.02.52.02.78 0a6.89 6.89 0 005-2l.06-.1v.91a2.5 2.5 0 00-1.92.72 2.82 2.82 0 00-.45 2.3c.03.11.1.21.19.28l.35.29c-1.25.42-2.56.6-3.87.55z"
          fill="#2F1D4A"
        />
        <path
          d="M480.66 383.82a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M486.25 389.26a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M476.13 393.37a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M510.36 390.49a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M516.07 385.18a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M519.69 395.48a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M510.46 367.73a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M504.69 362.49a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M514.66 358.02a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M491.97 362.32a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M486.22 367.57a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M482.69 357.24a1.88 1.88 0 100-3.76 1.88 1.88 0 000 3.76z"
          fill="#2F1D4A"
        />
        <path
          d="M253.62 366.16a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
          fill="#FDFFFC"
        />
        <path
          d="M255.78 366.37a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
          fill="#E0557A"
        />
        <path
          d="M260.65 361.04l-4-3.55 3.3-3.34a.78.78 0 00-.55-1.33.75.75 0 00-.54.23l-3.37 3.4-3.5-3.07a.76.76 0 00-1.28.62c.01.21.1.4.26.54l3.43 3-3.54 3.57a.75.75 0 00-.23.54.77.77 0 001.33.54l3.56-3.6 4.11 3.62c.1.08.2.14.33.17a.78.78 0 00.69-1.34z"
          fill="#2F1D4A"
        />
        <path
          d="M256.59 349.05a7.79 7.79 0 00-1.08 0 8.67 8.67 0 01-1.62 17.06c.35.08.71.14 1.07.18a8.68 8.68 0 001.63-17.28v.04z"
          fill="#3A1029"
        />
        <path
          d="M281.78 364.48a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
          fill="#FDFFFC"
        />
        <path
          d="M283.93 364.69a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
          fill="#F48352"
        />
        <path
          d="M310.02 362.18a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
          fill="#B39ED3"
        />
        <path
          d="M284.74 347.36a9.73 9.73 0 00-1.08 0 8.67 8.67 0 01-1.62 17.13 8.68 8.68 0 102.7-17.11v-.02z"
          fill="#40181D"
        />
        <path
          d="M278.4 357.77a.77.77 0 01-.65-.81.77.77 0 01.75-.72l9.05-.58a.78.78 0 01.63 1.28.76.76 0 01-.53.26l-9.05.58-.2-.01z"
          fill="#2F1D4A"
        />
        <path
          d="M404.6 590.99a4.73 4.73 0 00-.93-1.49.43.43 0 00-.14-.24l-19.07-17.47c-.76-.71-1.55-.23-.87.56l16.93 15.51a8.93 8.93 0 00-5 .43 9.19 9.19 0 00-3.44 2.23l.67.73a8.31 8.31 0 013.13-2 8.48 8.48 0 013-.56c.64 0 1.27.09 1.89.26a3.85 3.85 0 012.31 6.15 7.31 7.31 0 01-2.48 2.29c.97-.13 1.9-.48 2.72-1 .22-.24.42-.5.6-.76a5.13 5.13 0 00.68-4.64z"
          fill="#40181D"
        />
        <path
          d="M364.22 552.34c-.11.2-.21.42-.29.64l-4.06-3.72c-.4-.01-.8.1-1.14.31l21.71 19.88c1 .88 1.47.13.93-.5l-16.63-15.23c.06-.25.14-.49.26-.71l-.78-.67z"
          fill="#40181D"
        />
        <path
          d="M440.57 582.98a.5.5 0 00.3-.54 45.53 45.53 0 010-15.3c.22-1.23.53-2.43.94-3.61.34-.83-.43-1.39-.93-.41a44.11 44.11 0 00-1 3.82c-.8 4.41-.91 8.91-.34 13.36a6.16 6.16 0 00-3.42-.94c-.4 0-.82.04-1.22.11 0 .35.08.69.12 1 .36-.07.73-.1 1.1-.11 2.13 0 3.61 1 3.61 1.88 0 .66-.83 1.38-2.15 1.7a6.32 6.32 0 002.23.01c.33-.26.59-.6.76-.97z"
          fill="#40181D"
        />
        <path
          d="M444.67 556.32l.4-.79a.48.48 0 00.07-.24 3 3 0 00-.44-1.66 2.1 2.1 0 00-1.41-.37l-.26.36c.22.05.42.15.6.29a1.64 1.64 0 01.5 1.26 63 63 0 00-2.26 5.1c-.31 1.03.59 1.06 1 .25.41-.81 1-2.45 1.38-3.29l.22.07c.19-.36.36-.66.51-.89l-.31-.09z"
          fill="#40181D"
        />
        <path
          d="M466.36 565.63c-.35-.66-.72-1.3-1.11-1.94a32.36 32.36 0 00-9.9-10.56v-.61a2.07 2.07 0 00-1 .07v.31c-.2 0-.4.02-.6.05-.3.28-.52.62-.65 1l.22.26c.4-.26.9-.35 1.37-.27a31.43 31.43 0 019.71 10.32c.38.62.73 1.24 1.07 1.86.34.62 1.36.24.89-.49z"
          fill="#40181D"
        />
        <path
          d="M466.83 568.85a37 37 0 013.13 11.66 5.74 5.74 0 00-3.4-1.13c0 .37.08.7.11 1 1.91.11 3.21 1 3.21 1.85 0 .56-.61 1.17-1.6 1.53.55.13 1.12.2 1.68.19.42-.34.72-.8.86-1.32a.47.47 0 00.22-.39 34.31 34.31 0 00-3.26-13.75c-.39-.84-1.28-.33-.95.36z"
          fill="#40181D"
        />
        <path
          d="M256.68 544.55a2.54 2.54 0 111.9-2.45 2.23 2.23 0 01-1.9 2.45zm0-4.66c-.9 0-1.64 1-1.64 2.21s.74 2.2 1.64 2.2c.9 0 1.65-1 1.65-2.2 0-1.2-.74-2.21-1.65-2.21z"
          fill="#2F1D4A"
        />
        <path
          d="M492.31 297.31l-29.44 1.67 3.07 5.03 4.19.28.7 21.2-2.93.28-.98 5.17 28.33-.56-2.94-5.3-3.62.13-1.96-21.48 2.79-.42 2.79-6z"
          fill="#B39ED3"
        />
        <path
          d="M475.3 304.27c.78.06 1-.92-.12-1l-3.57.22c-.88.05-.74 1 .05 1l3.64-.22z"
          fill="#2F1D4A"
        />
        <path
          d="M458.92 315.72c.23.93 1.11.84 1.07-.09-.08-.51-.22-1-.29-1.51l20.52-5.01.15 5.76c.15 1 1 .7 1 0l-.29-10.92 1.94-.12a.49.49 0 00.44-.31l2.23-5.77a.5.5 0 00-.12-.55.5.5 0 00-.81.19l-2.12 5.47-4.42.25c-.73.12-.87 1 .09 1l1.8-.11.11 4.11-20.66 5c-.56-3.76-1-6.85-1.13-7.84l9.12-.55c.63 0 1-1-.05-1l-12.1.72-3-5.49a.5.5 0 00-.68-.2.5.5 0 00-.2.68l3.16 5.77a.52.52 0 00.44.26l2.3-.14c.16 1.35.8 5.94 1.5 10.4z"
          fill="#2F1D4A"
        />
        <path
          d="M486.08 331.03l-2.42-6.32a.47.47 0 00-.49-.32l-1.52.07-.18-6.63c0-.76-1.06-1-1 0l.1 3.86-20.14-2.7-.06-.42c-.29-.89-1-.65-1 .09l1 6.63v.12l-1.25.05a.52.52 0 00-.44.31l-2 5a.48.48 0 000 .38c.02.06.06.12.1.16.05.05.1.09.17.11a.51.51 0 00.65-.27l1.93-4.73 4-.19c.6-.06.79-.85-.11-1l-2.11.1a.41.41 0 000-.22l-.77-5.12 20 2.68v1.77l-14.19.66c-.75 0-.75 1 .11 1l16.29-.76 2.29 6a.48.48 0 00.46.32.54.54 0 00.38-.08c.05-.03.1-.09.14-.14a.5.5 0 00.06-.41z"
          fill="#2F1D4A"
        />
        <path
          d="M402.57 332.31l-6.84-10.52-2.89-.26-4-45s-.26-2.89 2.11-2.89 15-1.31 15-1.31l1.05 3.94 10.53 5.26-4-32.35-7.89 4.21.24 2.76-26.81 4.34s-2.63-.26-2.63 3.94 3.78 61.57 3.78 61.57l-3.68.26-1.32 6.85 27.35-.8z"
          fill="#B39ED3"
        />
        <path
          d="M417.15 275.86l-8.29-3.24-3.64-27.27 7.83-4.14a.5.5 0 00.2-.67.49.49 0 00-.3-.25c-.06-.02-.13-.02-.2-.02a.5.5 0 00-.18.06l-8.13 4.3a.49.49 0 00-.26.51l.47 3.54-22.49 2.43c-.78.19-.87.93.07 1l5.81-.64 1.25 19.15h-.32c-.94.11-1.81.52-2.49 1.18a1286.7 1286.7 0 01-21.57-16.82c.44-.43.98-.74 1.58-.88 1.14-.3 5.7-.88 11.29-1.53.76-.16.76-1-.11-1-5.64.66-10.25 1.25-11.44 1.57a4.34 4.34 0 00-3.16 5.19l1.1 9.1c0 .45 1.1.79 1-.08l-1.1-9.17c-.14-.8-.04-1.63.28-2.38 2.57 2.18 15.51 12.16 21.58 16.84-.14.35-.2.74-.15 1.12l.25 2.85-19.07 5.58s-1-8.71-1.17-9.76c-.17-1.05-1.08-.67-1 .15.08.82 5.17 42.93 5.17 42.93a.51.51 0 000 .24l.56 4.65a.54.54 0 000 .18c0 .11.04.22.1.31l.6 5.22-.95.11a.5.5 0 00-.39.28l-3.07 6.42a.5.5 0 10.9.43l3-6.17 22.84-2.72 5.14 9.2a.5.5 0 00.43.25c.09 0 .17-.02.25-.06a.5.5 0 00.19-.68l-5.34-9.46a.5.5 0 00-.5-.25l-2.52.3-2.13-23.91c-.1-.8-1.06-.8-1 .11l.44 5-17.66 9.81-2.79-23.17 19.53 3 .14 1.59c.11.93 1.06.61 1-.09l-.93-10.48c-.15-1.08-1-.92-1 0l.71 8-19.57-3-.88-7.36 19-5.57.42 4.75c.13.61 1 .52 1-.21l-.76-8.54c0-.16-.17-1.58 2.38-2 3.08-.54 18-1.63 18.36-1.66l.41 3.1a.49.49 0 00.31.4l8.56 3.35h.18a.5.5 0 00.52-.79.5.5 0 00-.33-.21l.04-.02zm-26.93 48l-18 2.14-.59-4.89 18.38.53.21 2.22zm-1.58-17.83l1.3 14.61-18.41-.53-.52-4.27 17.63-9.81zm1.64-35.61l-1.25-19.11 4.67-.5 9.32 18.45c-4.04.34-9.8.85-12.74 1.18v-.02zm13.82-1.24l-9.34-18.48 10-1 2.57 19.27-3.23.21z"
          fill="#2F1D4A"
        />
        <g id="window 2">
          <path
            d="M418.92 291.58l-12.28-104.65s-1.68-7.53 7-8.65 143.73-7.81 149-7.53c5.27.28 10.88-1.4 11.16 9.77.28 11.17-2.79 103-2.79 103s.56 8.09-6.42 9.21c-8 1.27-129.77 7.54-134.79 7.81-3.88.19-9.77-.03-10.88-8.96z"
            fill="white"
          />
          <path
            d="M562.64 170.75c-5.3-.28-140.37 6.42-149 7.53-8.63 1.11-7 8.65-7 8.65l3.58 30.85 163-7.4c.39-14.45.64-26.29.55-29.86-.25-11.17-5.83-9.49-11.13-9.77z"
            fill="#2F1D4A"
          />
          <path
            d="M434.45 176.92a.54.54 0 01-.18 0 .5.5 0 01-.27-.27.5.5 0 01-.01-.38l1.86-4.84a.48.48 0 01.42-.31l7.07-.56c.1-.01.2.01.3.06.08.05.15.13.19.22l2.42 5a.5.5 0 01-.07.55.5.5 0 01-.83-.11l-2.27-4.72-6.41.51-1.75 4.54a.51.51 0 01-.47.31z"
            fill="#2F1D4A"
          />
          <path
            d="M453.22 176.36h-.12a.5.5 0 01-.37-.42c-.01-.06 0-.13.01-.19l1.3-5.21a.48.48 0 01.45-.37l7.25-.56a.48.48 0 01.5.3l2.23 5.21c.03.06.04.13.05.2a.5.5 0 01-.14.36.5.5 0 01-.36.15.5.5 0 01-.36-.15.5.5 0 01-.11-.17l-2.09-4.88-6.54.51-1.21 4.86a.5.5 0 01-.49.36z"
            fill="#2F1D4A"
          />
          <path
            d="M430.92 299.95l-1.15.07c-4.56.25-9.36-.56-10.36-8.5l-.3-2.59c-.16-.74-1.1-.74-1 .13l.3 2.57c1.06 8.44 6.36 9.42 9.8 9.42.6 0 1.15 0 1.61-.06l1.14-.06c.75 0 .82-.95-.04-.98z"
            fill="#2F1D4A"
          />
          <path
            d="M572.22 263.11c.27-8.25.58-18.19.88-28.31 0-.7-1-.87-1-.08-.3 10.15-.61 20.14-.88 28.41.07.73.81.69 1-.02z"
            fill="#2F1D4A"
          />
          <path
            d="M571.98 269.11c0-.82-1-1.05-1 0l-.47 14.46c-.01.24.45 7.64-6 8.68-2.84.45-20.24 1.58-51.88 3.35-.78.11-.64 1.05.2 1 31.59-1.77 49-2.9 51.84-3.35 7.34-1.18 6.84-9.66 6.84-9.69l.47-14.45z"
            fill="#2F1D4A"
          />
          <path
            d="M408.13 181.62c1.1-1.55 3-2.51 5.55-2.84 7.91-1 142.9-7.86 148.93-7.53h2.13c4.65 0 8.33 0 8.56 9.24.12 4.83-.39 25-1 46.24.08.7.95.52 1-.11.62-21.2 1.13-41.33 1-46.16-.25-10.17-5-10.19-9.56-10.21h-2.08c-6-.31-141.19 6.51-149.11 7.54-2.88.37-5 1.47-6.24 3.27a8.15 8.15 0 00-1.17 5.93l11.35 96.76c.1 1.17 1.15.72 1-.11l-11.36-96.81a7.3 7.3 0 011-5.21z"
            fill="#2F1D4A"
          />
          <path
            d="M503.74 296.11c-18.09 1-40.14 2.18-66.17 3.55-.68.14-.68 1 .12 1 26.04-1.33 48.11-2.52 66.22-3.55.75-.08.93-1.13-.17-1z"
            fill="#2F1D4A"
          />
          <path
            d="M424.04 205.79a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
            fill="#FDFFFC"
          />
          <path
            d="M426.19 206a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
            fill="#E0557A"
          />
          <path
            d="M431.07 200.67l-4-3.55 3.3-3.34a.78.78 0 00-.55-1.33.75.75 0 00-.54.23l-3.37 3.4-3.5-3.08a.77.77 0 00-.89-.17.76.76 0 00-.4.47.77.77 0 00.29.86l3.43 3-3.5 3.55a.78.78 0 000 1.09.79.79 0 001.1-.01l3.56-3.6 4.11 3.61c.1.09.2.15.33.18a.77.77 0 00.86-.4.79.79 0 00-.17-.94l-.06.03z"
            fill="#2F1D4A"
          />
          <path
            d="M427.01 188.67a9.9 9.9 0 00-1.09 0 8.67 8.67 0 01-1.61 17.13 8.68 8.68 0 102.7-17.11v-.02z"
            fill="#3A1029"
          />
          <path
            d="M478.18 203a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
            fill="#FDFFFC"
          />
          <path
            d="M480.33 203.21a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
            fill="#EBB432"
          />
          <path
            d="M480.74 200.29l-.56-5.36 4.7-.21a.78.78 0 00-.08-1.55l-4.78.22-.48-4.63a.77.77 0 00-1.54.16l.47 4.54-5 .23a.79.79 0 00-.74.81c0 .14.06.28.14.4a.75.75 0 00.67.34l5.07-.23.56 5.44a.78.78 0 00.85.69.77.77 0 00.54-.27.76.76 0 00.18-.58z"
            fill="#2F1D4A"
          />
          <path
            d="M481.15 185.88a7.93 7.93 0 00-1.09 0 8.67 8.67 0 01-1.61 17.13 9.28 9.28 0 004.47-.13 8.7 8.7 0 001.52-16.05 8.7 8.7 0 00-3.29-.93v-.02z"
            fill="#3E2111"
          />
          <path
            d="M452.19 204.11a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
            fill="#FDFFFC"
          />
          <path
            d="M454.34 204.32a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
            fill="#F48352"
          />
          <path
            d="M455.16 186.99a9.73 9.73 0 00-1.08 0 8.68 8.68 0 01-1.62 17.12 8.68 8.68 0 102.7-17.11v-.01z"
            fill="#40181D"
          />
          <path
            d="M448.82 197.4a.78.78 0 01-.43-1.27.76.76 0 01.53-.26l9-.58a.77.77 0 11.1 1.54l-9.05.58-.15-.01z"
            fill="#2F1D4A"
          />
        </g>
        <g id="brokencontrol">
          <path
            d="M336.58 320.8c3.2-2.03 3.6-7.14.88-11.42-2.71-4.27-7.5-6.1-10.7-4.06-3.2 2.03-3.6 7.14-.88 11.42 2.71 4.27 7.5 6.1 10.7 4.06z"
            fill="#FDFFFC"
          />
          <path
            d="M339 316.35c3.63-2.34 4.06-8.17.94-13.02-3.12-4.86-8.6-6.9-12.24-4.56-3.64 2.34-4.06 8.17-.94 13.02 3.12 4.86 8.6 6.9 12.24 4.56z"
            fill="#EBB432"
          />
          <path
            d="M337.14 306.62c-.34-.38-.83-.44-1.07-.12l-2.58 3.19-3.85-4.16c-.34-.37-.82-.44-1.08-.13a1 1 0 00.17 1.23l3.86 4.18-2.67 3.3a1 1 0 00.18 1.22.78.78 0 00.95.24.5.5 0 00.13-.12l2.66-3.29 3.78 4.1a.77.77 0 001 .24c.05-.03.1-.07.13-.11a1 1 0 00-.17-1.23l-3.79-4.11 2.58-3.21a1 1 0 00-.23-1.22z"
            fill="#2F1D4A"
          />
          <path
            d="M316.01 346.75l-.16.47c-3.3 8.61-15.05 9.54-15.17 9.54a.5.5 0 00-.35.15.5.5 0 000 .7c.09.1.22.15.35.15.13 0 12.55-.92 16.1-10.18l.09-.26c-.29-.21-.58-.37-.86-.57z"
            fill="#2F1D4A"
          />
          <path
            d="M319.08 329.11a9 9 0 005.93-.95 9.3 9.3 0 011.73 5.99l1-.06v-.4c.04-2.2-.63-4.34-1.91-6.13a7.82 7.82 0 002.47-5.36.5.5 0 00-.49-.51.52.52 0 00-.51.49 6.89 6.89 0 01-2.08 4.59 9.31 9.31 0 00-4.39-3 5.1 5.1 0 00-5.11 1 2.07 2.07 0 00-.57 2.16c.27.76 1.18 1.77 3.93 2.18zm-2.63-3.63c.7-.64 1.64-.98 2.6-.94.5 0 1 .08 1.49.22a8.43 8.43 0 013.85 2.6 8 8 0 01-5.17.75c-1.71-.23-2.88-.78-3.13-1.49a1.17 1.17 0 01.36-1.19v.05z"
            fill="#2F1D4A"
          />
          <path
            d="M311.9 334.69a5.9 5.9 0 01.27-4.31 1.12 1.12 0 011-.57h.29a4.37 4.37 0 012.86 2.4c.37.7.66 1.44.85 2.21l1-.08a11 11 0 00-1-2.61 5.33 5.33 0 00-3.54-2.9 2.1 2.1 0 00-2.29 1 6.73 6.73 0 00-.48 4.77c.34.05.7.08 1.04.09z"
            fill="#2F1D4A"
          />
          <path
            d="M339.06 320.24c3.98-2.53 4.47-8.88 1.1-14.2-3.37-5.3-9.33-7.56-13.3-5.04-3.98 2.53-4.47 8.88-1.1 14.2 3.37 5.3 9.33 7.56 13.3 5.04z"
            stroke="#2F1D4A"
            strokeLinecap="round"
            strokeLinejoin="round"
          />
          <path
            d="M338.7 320.35c-1.42 1.14-3 2.09-4.66 2.82-3.72.68-8.21-1.62-11-6-2.45-3.86-2.86-8.27-1.38-11.36.56-1.16 3.08-3.35 4.3-4.33"
            stroke="#2F1D4A"
            strokeLinecap="round"
            strokeLinejoin="round"
          />
          <path
            d="M319.08 329.11a9 9 0 005.93-.95 9.3 9.3 0 011.66 6.35l1-.08c.04-.25.07-.5.08-.74.04-2.2-.63-4.34-1.91-6.13a7.82 7.82 0 002.47-5.36.5.5 0 00-.49-.51.52.52 0 00-.51.49 6.89 6.89 0 01-2.08 4.59 9.31 9.31 0 00-4.39-3 5.1 5.1 0 00-5.11 1 2.07 2.07 0 00-.57 2.16c.26.76 1.17 1.77 3.92 2.18zm-2.63-3.63c.7-.64 1.64-.98 2.6-.94.5 0 1 .08 1.49.22a8.43 8.43 0 013.85 2.6 8 8 0 01-5.17.75c-1.71-.23-2.88-.78-3.13-1.49a1.17 1.17 0 01.36-1.19v.05z"
            fill="#2F1D4A"
          />
          <path
            d="M312.4 338.21a7.37 7.37 0 005 3.17 26.5 26.5 0 01-1.49 5.73c.27.25.52.51.76.79l.14-.32a27.56 27.56 0 001.58-6.11c.85.01 1.7-.08 2.53-.28 3.84-.91 6.22-3.25 6.74-6.49h-1c-.36 1.95-1.68 4.48-6 5.49-.71.18-1.45.27-2.18.26a19 19 0 00-.23-5.55h-1c.36 1.8.44 3.63.24 5.45a6.27 6.27 0 01-4.27-2.75 8.53 8.53 0 01-1.2-2.58h-1.05c.29 1.14.77 2.22 1.43 3.19z"
            fill="white"
          />
        </g>
      </MainWindows>
      <g>
        <CablePlug
          d="M210.42 399.94C207.02 400.733 203.72 401.903 200.58 403.43C194.29 406.6 191.32 410.6 192 415.01C192.109 416.221 192.571 417.373 193.331 418.323C194.09 419.273 195.112 419.978 196.27 420.35C196.921 420.537 197.593 420.638 198.27 420.65C198.27 420.65 198.81 420.65 199.47 420.65C202.199 420.273 204.708 418.949 206.56 416.91C207.86 415.52 208.33 414.26 207.93 413.28C207.698 412.839 207.346 412.473 206.914 412.225C206.482 411.977 205.988 411.857 205.49 411.88H205.25C204.295 411.892 203.36 412.158 202.543 412.652C201.725 413.146 201.054 413.85 200.6 414.69C199.75 416.38 199.182 418.197 198.92 420.07C198.92 420.17 198.76 421.27 198.76 421.27C198.21 425.68 198.32 431.53 199.12 441.48C200.03 452.59 200.74 501.77 187.22 521.48C180.02 531.97 160.76 538.35 145.86 541.85C129.263 545.653 112.331 547.804 95.31 548.27C90.99 548.34 86.98 548.22 83.4 547.92C80.88 547.63 76.74 547.03 76.74 547.03C71.07 545.95 67.4 544.16 66.13 541.86C65.29 540.34 65.47 538.57 66.66 536.74C68.99 533.14 77.56 532 84.21 532.09C90.56 532.2 97.72 533.56 99.4 536.36C99.7398 536.873 99.9301 537.47 99.9495 538.084C99.9689 538.699 99.8168 539.307 99.51 539.84C97.93 542.71 92.34 545.16 83.34 546.92L76.67 548C66.9121 549.234 57.0942 549.935 47.26 550.1C46.09 550.1 44.92 550.1 43.75 550.1C25.37 550.1 7.21998 546.34 5.64998 537.58C4.87998 533.34 8.98998 529.13 16.37 526.58C21.59 524.79 27.06 523.12 32.37 521.5L32.78 521.38C49.3 516.38 59.32 512.99 59.3 509.38C59.3 507.48 56.3 505.69 50.25 503.91C44.2351 502.367 38.0385 501.647 31.83 501.77C19.93 501.77 4.65998 503.99 0.759978 510.23C0.44301 510.701 0.27958 511.259 0.292113 511.826C0.304647 512.394 0.492536 512.943 0.829986 513.4C3.69999 517.8 16.77 521.1 32.62 521.4H32.78C40.6178 521.525 48.453 521.02 56.21 519.89C72.14 517.58 82.57 512.48 87.21 504.71C90.67 498.92 90.88 491.71 87.83 483.43C82.31 468.33 86.67 451.22 86.71 451.05"
          stroke="#2F1D4A"
          strokeLinecap="round"
        />
        <CableWindow1
          d="M449.67 100C449.88 100 470.67 100.15 471.44 113.58C471.93 122.43 467.35 129.14 462.91 135.58C459.57 140.46 456.12 145.51 455.07 151.31C453.01 162.76 457.84 169.63 458.07 169.91"
          stroke="#2F1D4A"
          strokeLinecap="round"
        />
        <CableWindow2
          d="M449.12 75.66C449.4 75.66 477.47 77.99 482.79 100.03C487.04 117.62 469.94 131.03 457.45 140.77C452.7 144.49 448.61 147.7 446.51 150.45C438.43 161.11 439.58 170.88 439.63 171.29"
          stroke="#2F1D4A"
          strokeLinecap="round"
        />
      </g>
      <SecondWindow>
        <path
          d="M439.03 116.58l-164.95.31a6.12 6.12 0 01-6.12-6.12l-5.32-63.66a6.12 6.12 0 016.11-6.12l169.45-5a6.12 6.12 0 016.11 6.12l.84 68.37a6.1 6.1 0 01-6.12 6.1z"
          fill="white"
        />
        <path
          d="M334.66 117.28s44.65-.1 45.67-.09c1.02.01.94-.89-.07-1-1.01-.11-45.6.09-45.6.09-.74.07-.88 1 0 1z"
          fill="#2F1D4A"
        />
        <path
          d="M434.22 116.11s-49 0-49.77.09c-.77.09-1.18 1 0 1l49.77-.09c.91-.06 1-.92 0-1z"
          fill="#2F1D4A"
        />
        <path
          d="M444.81 42.11a6.63 6.63 0 00-6.59-6.63l-169.43 5a6.63 6.63 0 00-6.65 6.63l5.32 63.63a6.63 6.63 0 006.62 6.62l56.14-.11c.74 0 1.05-1-.07-1l-56.07.11a5.63 5.63 0 01-5.62-5.66l-5.32-63.59a5.63 5.63 0 015.63-5.62l169.43-5a5.62 5.62 0 015.61 5.62l.84 68.37a5.62 5.62 0 01-5.62 5.61c-.75.08-.72 1.1 0 1a6.61 6.61 0 006.62-6.62l-.84-68.36z"
          fill="#2F1D4A"
        />
        <path
          d="M444.87 82.36a.48.48 0 01-.45-.29.5.5 0 01.24-.66l4.29-2-.5-6.95-3.68-.76a.5.5 0 01-.17-.9c.1-.08.24-.1.37-.08l4 .84a.5.5 0 01.4.45l.55 7.68c0 .1-.02.2-.07.29a.5.5 0 01-.22.2l-4.6 2.09a.53.53 0 01-.16.09z"
          fill="#2F1D4A"
        />
        <path
          d="M445.29 106.22a.5.5 0 01-.44-.26.5.5 0 01.2-.68l3.92-2.09-.13-6.22-3.91-2a.5.5 0 01-.25-.29.51.51 0 01.02-.38.51.51 0 01.67-.23l4.19 2.1a.5.5 0 01.28.43l.14 6.84a.5.5 0 01-.27.45l-4.19 2.24a.46.46 0 01-.23.09z"
          fill="#2F1D4A"
        />
        <path
          d="M336.27 83.53a.5.5 0 00-.27-.29l-15.78-6.8 3.14-36.91a.5.5 0 00-.45-.54.51.51 0 00-.54.46l-5.18 60.74a.51.51 0 00.46.54.51.51 0 00.5-.46l1.94-22.78 15.31 6.62 3.72 10.36a.52.52 0 00.47.33h.17a.48.48 0 00.29-.26.48.48 0 00.01-.38l-3.79-10.63z"
          fill="#2F1D4A"
        />
        <path
          d="M445.22 90.28l-14.61-5.94-1.11-34.23a.51.51 0 00-.51-.48.5.5 0 00-.46.32.5.5 0 00-.03.19l.38 12c-4.79-2.23-15.84-7.33-16.67-7.33a.52.52 0 00-.52.5.47.47 0 00.13.35.48.48 0 00.35.15c.83.14 10.47 4.53 16.35 7.27h.39l.65 20.91-7.68-3.13a.5.5 0 10-.38.93l23.3 9.48h.19c.23-.02.44-.88.23-.99z"
          fill="#2F1D4A"
        />
        <path
          d="M393.44 108.62l-1.87-16a.5.5 0 00-.5-.45.5.5 0 00-.23.06l-13 6.77a.51.51 0 00-.25.3.5.5 0 00.04.38.5.5 0 00.67.21l12.36-6.44 1.81 15.54a.53.53 0 00.21.35l10.54 7.55c.08.07.2.1.3.1a.53.53 0 00.4-.21.5.5 0 00-.11-.7l-10.37-7.46z"
          fill="#2F1D4A"
        />
        <path
          d="M444.31 42.11a6.12 6.12 0 00-6.09-6.13l-169.45 5a6.12 6.12 0 00-6.13 6.13l2 23.4c21.43-.45 159.68-3.42 180-4.47l-.33-23.93z"
          fill="#2F1D4A"
        />
        <path
          d="M323.3 39.37h-1l-2.55 29.85h1l2.53-29.74a.32.32 0 00.02-.11z"
          fill="white"
        />
        <path
          d="M389.8 35.46l-28.37 1.89-.28.42-16.11 79.93 29.21.87 11.5-57.55 24.51 58.04 17.41-.84-37.87-82.76z"
          fill="white"
        />
        <path
          d="M384.72 36.46l-18.69.65a4.9 4.9 0 01-1.11-1.81l-.28-1s-17.58-8.65-20.09-11.3c-2.51-2.65-5-5-3.77-9.21 1.23-4.21 6-12.14 8.79-13 2.79-.86 6.14 1.12 9.63 6.7 3.49 5.58 10.45 20.75 10.45 20.75s10.62-4.84 12-5c1.38-.16 3 2.51 3 2.51s21.67-13.54 24.2-14.58c2.53-1.04 3.51-.21 4.49 3.14.98 3.35 1 16.19 0 19a11.2 11.2 0 01-2.17 4l-26.45-.83"
          fill="white"
        />
        <path
          d="M268.87 116.52c1.3 1.86 6.51 1.86 6.51 1.86l40-.38-50.6-37.76.67 10.71-6.23 1.57s-1.31.18-1.12 1.86c.19 1.68 2.05 10.6 2.05 10.6s-.1.48.92 1c-.44 2-1.29 4.8-2.78 6.3-2.42 2.41-6.52 4.65-7.07 7.25-.38 2.34-.56 4.7-.56 7.07l8.18 3s.75 5.95 2 8.74a31.02 31.02 0 001.86 3.72l7.44-7.44s-4.09-5.21-4.83-11c-.48-3.66.55-9.65 1.37-13.53.24 2.28.99 4.48 2.19 6.43z"
          fill="white"
        />
        <path
          d="M272.08 80.98c-.14.56.14 8.23.14 8.23s25.67 20.65 25.26 20.51c-.41-.14-25.4-15.34-25.4-15.34l-8.09.83s-1-.28-.84 1c.16 1.28 1.12 10.9 1.12 10.9s-1.82 7.82-4.89 11.45c-3.07 3.63-3.35 14-3.35 14l6.42 1.39a9.64 9.64 0 001.82 4.47 47.79 47.79 0 003.62 4.46l6.7-8.09s-5.58-2.79-5.58-12.14c0-9.35.28-18.42.28-18.42l6.56 14a6.42 6.42 0 006 4.32c4.74.14 15.07-.28 15.07-.28l-13.12-13 19.42 12.18 20.93-.28-52.07-40.19z"
          fill="#B39ED3"
        />
        <path
          d="M366.92 30.93s-14-12.46-15.63-19.34c-1.63-6.88.56-10.42 5.77-5.59 5.21 4.83 13.21 23.45 13.21 23.45l-3.35 1.48z"
          fill="#B39ED3"
        />
        <path
          d="M389.06 37.63l22.16-.52s3.16-8.18 3.16-11.35-1.12-5.2-5.95-4.27c-4.83.93-22.43 11-22.51 11.52a3 3 0 00-1.31-1.29c-1.11-.56-19.16 4.28-18.79 5 .5.64 1.13 1.15 1.86 1.49l-16 82.79h10c.56 0 14.32-58.05 14.32-58.05s-9.3 57.31-8.93 57.86c.37.55 5.21.19 5.77 0 .56-.19 13.58-60.27 13.58-60.27l-1.67-2.8s-7.93 26.19-9.43 32c1.13-6.41 5.71-37.57 5.71-37.57l-4.28-13.76 3.35.18 35.72 79.07 2.6-.37-25.3-60.84s28.84 60.47 29.21 61c.37.53 4.09 0 4.09 0l-37.36-79.82zm-29.58 54.33l10.79-53.58 3-.75-13.79 54.33z"
          fill="#B39ED3"
        />
        <path
          d="M278.56 64.03a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
          fill="#FDFFFC"
        />
        <path
          d="M280.71 64.23a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
          fill="#E0557A"
        />
        <path
          d="M285.58 58.91l-4-3.56 3.3-3.34a.78.78 0 00-.55-1.33.76.76 0 00-.54.23l-3.37 3.4-3.49-3.07a.78.78 0 00-1.1.06.8.8 0 00.07 1.1l3.43 3-3.49 3.54a.75.75 0 00-.23.55.77.77 0 00.23.54c.1.1.23.17.37.21a.83.83 0 00.73-.21l3.56-3.61 4.06 3.69a.78.78 0 001.09-.07.77.77 0 00-.07-1.13z"
          fill="#2F1D4A"
        />
        <path
          d="M281.52 46.91a7.88 7.88 0 00-1.08 0 8.67 8.67 0 01-1.62 17.1c.35.08.71.14 1.07.18a8.68 8.68 0 001.63-17.28z"
          fill="#3A1029"
        />
        <path
          d="M332.69 61.24a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
          fill="#FDFFFC"
        />
        <path
          d="M334.85 61.44a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
          fill="#EBB432"
        />
        <path
          d="M335.22 58.52l-.55-5.35 4.69-.22a.78.78 0 00-.08-1.55l-4.78.22-.48-4.63a.77.77 0 00-1.54.16l.48 4.55-5 .23a.77.77 0 00-.73.81c0 .14.05.28.13.39a.75.75 0 00.68.34l5.06-.23.57 5.44c0 .13.05.25.12.36a.8.8 0 00.72.33.75.75 0 00.68-.54c.03-.1.04-.2.03-.31z"
          fill="#2F1D4A"
        />
        <path
          d="M335.66 44.11a7.88 7.88 0 00-1.08 0 8.67 8.67 0 01-1.62 17.13 8.7 8.7 0 102.7-17.13z"
          fill="#3E2111"
        />
        <path
          d="M305.71 62.34a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
          fill="#FDFFFC"
        />
        <path
          d="M307.86 62.55a8.68 8.68 0 100-17.36 8.68 8.68 0 000 17.36z"
          fill="#F48352"
        />
        <path
          d="M308.67 45.23a7.88 7.88 0 00-1.08 0 8.67 8.67 0 01-1.62 17.13c.35.08.71.14 1.07.18a8.68 8.68 0 001.63-17.28v-.03z"
          fill="#40181D"
        />
        <path
          d="M302.33 55.63a.77.77 0 01.1-1.53l9.05-.58a.78.78 0 01.63 1.28.77.77 0 01-.53.26l-9.05.58-.2-.01z"
          fill="#2F1D4A"
        />
        <path
          d="M353.33 80.24c.1-.75-.72-1.17-1-.12l-7.29 37.58a.47.47 0 00.11.41.47.47 0 00.38.19h4.45c1.08 0 .77-1.07 0-1-.77.07-3.84 0-3.84 0l7.19-37.06z"
          fill="#2F1D4A"
        />
        <path
          d="M358.45 53.84c.21-1-.77-1.16-1-.3l-4 20.67c-.19 1.1.81 1 1 .11l4-20.48z"
          fill="#2F1D4A"
        />
        <path
          d="M409.58 78.28c-.43-.88-1.41-.46-.92.4l6.78 14.94c.41.85 1.29.38.93-.38l-6.79-14.96z"
          fill="#2F1D4A"
        />
        <path
          d="M398.84 31.68c2.6-.84 5.28-1.4 8-1.64 2.29-.06 2.89.37 2.91.53.07.38-1.16 1.57-3.64 2.4-2.48.83-13 3.73-13.09 3.76a.5.5 0 00-.37.42.5.5 0 00.5.56c.05.01.1.01.14 0 .43-.12 10.67-2.95 13.14-3.77 2.24-.75 4.55-2.17 4.31-3.52-.17-1-1.46-1.42-3.92-1.36a38 38 0 00-8.13 1.65c.02.31.09.64.15.97z"
          fill="#2F1D4A"
        />
        <path
          d="M427.67 118.22c-.07-.2-4.25-9.44-9.81-21.69-.41-.71-1.32-.6-.9.43 4.83 10.65 8.62 19 9.55 21.09-2.11.21-10.45.13-15.91 0l-34-81.61h12.88l16.54 36.4c.44 1 1.32.42.9-.43l-16.7-36.66a.5.5 0 00-.46-.29h-2.31c1.91-.7 4.67-1.69 7.58-2.62l-.43-.93c-3.36 1.1-6.7 2.28-10 3.55h-1a36.53 36.53 0 001.18-8.5s.06 0 .08-.06c.48-.46 5.33-3.89 10.57-7.43l-.41-1c-4.5 3-8.75 5.93-10.37 7.26a3.5 3.5 0 00-.14-.58c-.68-2-1.66-2.6-3.74-2.19a90.75 90.75 0 00-10.23 4.77c-.64-1.41-3.3-7.2-6.48-13.07-.36-.72-1.31-.41-.92.42 3.22 6 6 11.88 6.51 13.12-3 1.61-5.51 3.13-5.8 3.8-.16.46-.18.96-.06 1.44-1.63-.76-5.63-2.71-9.73-5-.9-.46-1.25.41-.46.89 5.36 3 10.5 5.33 10.6 5.37.22.5.47.99.75 1.46l-3.71.07a.48.48 0 00-.48.4l-2.44 12.63c-.26 1.19.78 1 1 .14l2.35-12.12 13.83-.26a.87.87 0 00.23-.07l1.11 2.67-19.73 77.79s-2.6-.11-3.59 0c-.99.11-1.13 1 0 1l20.73.2a.49.49 0 00.49-.41s2.06-10.61 2.22-11.52c.16-.91-.85-.89-1 0-.15.89-2.1 10.9-2.1 10.9l-15.7-.14 19.33-76.26s7.73 18.26 7.73 18.46l-8.4 42.47c-.08.81.72 1 1 .13l7.93-41.21 24.06 57.74a.5.5 0 00.45.31c4.39.1 7.65.13 10.08.13 6.9 0 7.12-.3 7.26-.49a.55.55 0 00.07-.5zm-51.16-92.34a33.44 33.44 0 014.46-1.9c1.58-.32 2.07 0 2.59 1.53.87 2.62-.92 9.69-.94 9.77a.37.37 0 000 .18h-3.31a.49.49 0 00-.19-.28c-4.03-2.86-2.69-8.95-2.61-9.3zm-10.42 10.31a.51.51 0 00-.06-.14c-.71-1.06-1.57-2.89-1.27-3.6.32-.52 2.94-2.05 6-3.67a8.87 8.87 0 00-.66 7.34l-4.01.07zm9.34-.51a.44.44 0 00-.06.34l-4.24.08a.29.29 0 000-.16c-1.71-3.77 1.22-7.83 1.25-7.87.04-.05.06-.1.07-.16l3-1.49c-.29 1.83-.59 6.28 2.49 9h-2a.5.5 0 00-.51.26z"
          fill="#2F1D4A"
        />
        <path
          d="M358.94 7.91c.9 1.4 1.82 2.94 2.72 4.53.43.56 1.3.18.73-.75-.8-1.42-1.64-2.8-2.52-4.18-.46-.68-1.3-.4-.93.4z"
          fill="#2F1D4A"
        />
        <path
          d="M357.22 5.36c.46.63 1.36.32.9-.37-1-1.51-2.25-2.84-3.7-3.92a5.63 5.63 0 00-4.48-.92c-3 .78-5 4.46-6.8 7.71l-.59 1.06c-2.64 4.74-3.78 7.23-.68 12.1 1.12 1.75 4.3 4 7.91 6.19.61.38 1.23-.18.62-.8-3.56-2.14-6.66-4.32-7.69-5.93-2.8-4.4-1.86-6.45.72-11.07l.59-1.07c1.68-3.07 3.59-6.55 6.17-7.23a4.63 4.63 0 013.7.81c1.3.96 2.43 2.13 3.33 3.46v-.02z"
          fill="#2F1D4A"
        />
        <path
          d="M414.13 25.78c-.12 2.37-.5 4.72-1.13 7a11.06 11.06 0 01-1.89 3.96.49.49 0 000 .39.5.5 0 00.11.16c.1.09.22.14.35.14a.5.5 0 00.35-.14 11 11 0 002.08-4.25 32.15 32.15 0 001.18-7.21l-1.05-.05z"
          fill="#2F1D4A"
        />
        <path
          d="M413.41 16.69c.4 1.6.65 3.24.73 4.89h.08c.25-.25.57-.43.92-.49-.1-1.57-.35-3.12-.73-4.64-1.48-5.66-2.37-7.08-5.77-6.22-.89.22-5.16 2.82-9.9 5.88 0 .14.07.28.1.42.03.14.18.34.27.51 4.53-3 8.66-5.57 9.77-5.84 2.24-.58 2.97-.48 4.53 5.49z"
          fill="#2F1D4A"
        />
        <path
          d="M353.34 16.74c1.9 2.42 4.12 4.94 6 7 .53.56 1.34 0 .77-.64-1.87-2-4.08-4.55-6-6.93-.39-.62-1.23-.27-.77.57z"
          fill="#2F1D4A"
        />
        <path
          d="M366.22 26.52c-.6-1.19-7.83-13.85-11.35-18.49-1.87-2.47-3.92-2.81-5-2.09-1.08.72-1.69 2.7.15 6 .48.84 1 1.65 1.57 2.43.37.61 1.31 0 .82-.57a26.12 26.12 0 01-1.52-2.35c-1.4-2.49-1.22-4.16-.47-4.65.75-.49 2.27 0 3.68 1.85 3.49 4.6 10.66 17.15 11.26 18.34.34.68.23 1.06.14 1.13-.09.07-.53 0-1.16-.59 0 0-.88-.9-2.12-2.21-.64-.61-1.37-.09-.76.65l2.17 2.27a2.51 2.51 0 001.73.91c.25 0 .5-.07.71-.22.57-.46.64-1.39.15-2.41z"
          fill="#2F1D4A"
        />
        <path
          d="M299.49 105.36l-11.92-8.85c-.63-.51-1.21.26-.6.8l11.89 8.8c.52.47 1.29-.2.63-.75z"
          fill="#2F1D4A"
        />
        <path
          d="M251.46 121.27c.12-.72.05-.23.08-.35a9 9 0 013-4.65c.59-.46-.11-1.3-.76-.66a9.91 9.91 0 00-3.22 5.06c0 .17-.06-.3-.12.52-.06.82.91.8 1.02.08z"
          fill="#2F1D4A"
        />
        <path
          d="M315.96 117.6l-12.74-9.43c-.69-.61-1.32.28-.7.72l11.7 8.63-5.93.06c-.34-.16-34.11-16.65-34.2-16.64l-8.3-11-.55-8.78 18 13.41c.55.48 1.3-.17.68-.74l-19-14.11a.5.5 0 00-.8.43c0 .43.28 4.52.61 9.67a.5.5 0 000 .47l-6.16 2a.6.6 0 00-.15.09 2.33 2.33 0 00-.89 1.64c0 .72 1.87 9.51 2.27 11.36.14.31.32.6.54.86a.46.46 0 00-.14.22s-1.24 4.73-3.87 7c-.53.61.31 1.16.85.58 2.55-2.34 3.78-6.54 4-7.22.47.15 1.23.35 2 .55-.41 1.65-1.86 7.38-3.07 10.64a32.02 32.02 0 00-1.79 11l-7.1-2.45c0-.39-.09-1.35-.1-2a.51.51 0 00-.1-.42.5.5 0 00-.4-.19.5.5 0 00-.5.61c0 .83.05 1.66.15 2.48a.52.52 0 00.33.41l7.72 2.66c.07 1.85.43 3.67 1.05 5.41a65.58 65.58 0 003 6.9.49.49 0 00.37.26h.07a.5.5 0 00.36-.15l7.39-7.67a.5.5 0 00.06-.63 36.5 36.5 0 01-2.5-4.78c-.36-.66-1.23-.42-.88.51a37.97 37.97 0 002.33 4.48l-6.63 6.89a35.64 35.64 0 01-2.6-6.16c-2.07-6.7-.41-13.8.7-16.81 1.23-3.31 2.7-9.08 3.11-10.75l1.84.44.22 2.58a36.7 36.7 0 00-1.25 10.64c.11 1.79.45 3.55 1 5.25.32.7 1.23.28.85-.67-.46-1.5-.74-3.05-.83-4.62-.07-2.7.12-5.4.59-8.07a7.14 7.14 0 002.71 4.4 8.87 8.87 0 005.21 1.53h.16c.75 0 .88-1-.05-1a8.26 8.26 0 01-4.73-1.35 6.57 6.57 0 01-2.5-4.77c-.61-6.74-1.1-13.49-1.49-20.24l19.63 26.13s-6.23.08-7.14.07c-.91-.01-1 1 0 1s37.31-.4 37.31-.4a.5.5 0 00.47-.34.52.52 0 00-.19-.59zM264.8 91.25l.38 5.79-.61.82-5-4.87 5.23-1.74zM258.53 94a.88.88 0 01.16-.45l5.26 5.13-3.54 4.76c-.83-3.93-1.86-8.96-1.88-9.44zm7.35 13c-.94-.22-3.49-.83-4.48-1.16-.28-.18-.5-.44-.64-.75a2.9 2.9 0 01-.07-.32l4.59-6.17.6 8.37v.03zm20.79 10.85a.57.57 0 00-.05-.12l-11.4-15.22 30.84 15.1-19.39.24z"
          fill="#2F1D4A"
        />
        <path
          d="M429.5 50.11a.51.51 0 00-.51-.48.5.5 0 00-.46.32.5.5 0 00-.03.19l.38 12c-4.79-2.23-15.84-7.33-16.67-7.33a.52.52 0 00-.52.5.47.47 0 00.13.35.48.48 0 00.35.15c.83.14 10.47 4.53 16.35 7.27h.39l.11 3.58h1l-.52-16.55z"
          fill="white"
        />
      </SecondWindow>
      <Smoke>
        <g>
          <path
            d="M589.45 329.63s-4.67 6.17 1.78 9.71c7.92 4.34 10.62-6.59 10.62-6.59s10.84 1.16 10.74-7.77c-.09-8.28-10-6.74-10-6.74s-7.72-9.91-15.07-2c-6.06 6.55 1.93 13.39 1.93 13.39z"
            fill="#B39ED3"
          />
        </g>
        <g>
          <path
            d="M612.13 275.21c-.19-.56-6.14-15.07 3-21.58 9.14-6.51 18.42-2.42 21.77 3.16a10.91 10.91 0 01.19 10.79s6.42-1.18 8.18 4.28c1.86 5.77-2.42 7.63-2.42 7.63s9.68 9.3 3 16.75c-6.68 7.45-18.05-1.68-18.05-1.68s-1.3 3.72-5 4.28-6.7-2.42-6.7-2.42-8.08 5.39-14.14-1.67c-4.46-5.21-3.16-14 .93-16.75 5.02-3.47 9.24-2.79 9.24-2.79z"
            fill="#B39ED3"
          />
          <path
            d="M626.45 292.46a.5.5 0 01-.35-.16.5.5 0 01-.14-.36 18.34 18.34 0 00-2.89-9.75 11.2 11.2 0 00-8.16-4.62.5.5 0 01-.32-.86c.1-.09.22-.14.35-.14a11.99 11.99 0 019 5.06c2 3.08 3.06 6.67 3.06 10.34a.51.51 0 01-.55.49z"
            fill="white"
          />
          <path
            d="M624.78 279.81a.5.5 0 01-.35-.15.5.5 0 01-.15-.35c0-.87 1.1-6.15 6.32-10.44a.5.5 0 01.8.24.5.5 0 01-.04.39.49.49 0 01-.13.15 16.1 16.1 0 00-6 9.66.51.51 0 01-.45.5z"
            fill="white"
          />
        </g>
        <g>
          <path
            d="M613.61 219.77s-18.14-1.76-20.09-19.16c-2.23-19.91 16.75-21.58 16.75-21.58s.74-13.52 13.2-15.82c12.1-2.23 15.63 4.65 15.63 4.65s8.75-16.93 30-4.28c21.25 12.65 11.53 31.63 6.51 35.54s-14.14 3.72-14.14 3.72 6.7 7.63-.75 14.51-16.18 1.12-16.18 1.12 2.79 16.74-15.82 16.56c-16.26-.17-15.11-15.26-15.11-15.26z"
            fill="#B39ED3"
          />
          <path
            d="M633.89 208.55a.5.5 0 01-.49-.44c0-.12-1.59-11.93-12.24-13.71a12.78 12.78 0 00-11.68 3.89 18.71 18.71 0 00-3.68 5.3.5.5 0 01-.92 0 .51.51 0 01-.01-.38c.05-.12 5-11.69 16.45-9.79 11.45 1.9 13 14.44 13.07 14.57a.51.51 0 01-.44.56h-.06z"
            fill="white"
          />
          <path
            d="M630.92 197.95a.5.5 0 01-.28-.09.5.5 0 01-.14-.69c.07-.1 6.82-10.13 16.72-7.65a.5.5 0 01.37.6.52.52 0 01-.61.37c-9.22-2.3-15.58 7.14-15.65 7.23a.48.48 0 01-.41.23z"
            fill="white"
          />
        </g>
      </Smoke>
      <Spinner>
        <path
          d="M494.85 256.23a14.63 14.63 0 100-29.26 14.63 14.63 0 000 29.26z"
          fill="#F58452"
        />
        <path
          d="M481.22 246.81a14.62 14.62 0 0012.09 9.3 24.2 24.2 0 01-.94-6.81c.12-2.9 1.01-5.73 2.57-8.19-3.38-.37-6.79.37-9.71 2.1a17.9 17.9 0 00-4.01 3.6z"
          fill="#E1557A"
        />
        <path
          d="M493.31 256.18a15.4 15.4 0 0014.37-7.07 23.87 23.87 0 01-6.53-2.14 16.67 16.67 0 01-6.24-5.9s-5.24 6.97-1.6 15.11z"
          fill="white"
        />
        <path
          d="M507.6 249.11c3-4.51 2.72-10.06 0-14.92a20.89 20.89 0 01-4.73 4.1 16.28 16.28 0 01-8 2.68 15.72 15.72 0 007.37 6.65c1.7.76 3.5 1.26 5.36 1.49z"
          fill="#2F1D4A"
        />
        <path
          d="M507.49 234.11a14.43 14.43 0 00-13.38-7.18c.9 1.77 1.48 3.68 1.74 5.65.37 2.89-.03 5.82-1.15 8.51a16.73 16.73 0 0012.79-6.98z"
          fill="#B39ED3"
        />
        <path
          d="M494.22 226.97a14.61 14.61 0 00-12.5 8.17c2.19.1 4.35.5 6.43 1.19 2.59.98 4.88 2.63 6.63 4.77a15 15 0 001-9.39 15.42 15.42 0 00-1.56-4.74z"
          fill="#EBB432"
        />
        <path
          d="M494.09 254.11c-.39 0-.79.06-1.19.06a14.12 14.12 0 01-11.93-6.59c-.56-.77-1.17-.3-.85.53a15.13 15.13 0 0012.78 7.06c.52 0 1.05 0 1.56-.08.97.02.88-1.09-.37-.98z"
          fill="#2F1D4A"
        />
        <path
          d="M492.9 224.94c-1.13 0-2.26.13-3.36.39-.72.3-.48 1.05.42.92a14.12 14.12 0 018.68 26.72c-.75.34-.51 1.31.33.94a15.12 15.12 0 00-6.07-29v.03z"
          fill="#2F1D4A"
        />
        <path
          d="M483.44 229.6c.92-.71.36-1.5-.49-.9a15.09 15.09 0 00-4.45 16c.51 1.06 1.39.46.92-.41a14.07 14.07 0 014.02-14.69z"
          fill="#2F1D4A"
        />
      </Spinner>
      <Alert>
        <path
          d="M556.95 266.47h-25.09c-3.34 0-7.18-2.23-5.5-6 1.36-3 13.36-33.86 13.36-33.86 1.07-3.9 6.16-3.34 7.5-.18 0 0 13.52 31.62 14.67 34 1.86 3.99-1.6 6.04-4.94 6.04z"
          fill="#F58452"
        />
        <path
          d="M539.93 246.3l-2.02-16.77 6.42-.27-2.13 17.17-2.27-.13z"
          fill="#2F1D4A"
        />
        <path
          d="M541.73 255.66a2.61 2.61 0 100-5.22 2.61 2.61 0 000 5.22z"
          fill="#2F1D4A"
        />
        <path
          d="M533.5 229.9c.5-.79-.48-1.45-.91-.42l-3.33 8.51c-.22.78.55 1 1 .21l3.24-8.3z"
          fill="#BF5328"
        />
        <path
          d="M536.67 221.76a3 3 0 012.8-2.37h.25a3.83 3.83 0 013.5 2.26c.38.88 6.53 15.26 10.77 25.09.31.8 1.36.48.94-.34-4.34-10-10.7-24.92-10.79-25.14a4.83 4.83 0 00-4.74-2.85 4 4 0 00-3.68 3.05l-1.78 4.55c-.26.81.48 1.19.92.4 1.01-2.58 1.69-4.3 1.81-4.65z"
          fill="#BF5328"
        />
        <path
          d="M557.62 252.59c-.49-1.12-1.4-.77-1 .17l1.31 3a3.27 3.27 0 01.06 3.28c-.75 1.19-2.54 1.95-4.56 1.95h-25.1a6.08 6.08 0 01-5-2.2 3 3 0 01-.09-3c.57-1.27 3-7.33 5.59-14 .35-.71-.42-1.44-1-.26-2.6 6.61-5 12.6-5.53 13.84a4 4 0 00.16 4c1.19 1.84 3.77 2.66 5.8 2.66h25.08c2.39 0 4.47-.92 5.41-2.41a4.2 4.2 0 000-4.25c-.11-.44-.53-1.4-1.13-2.78z"
          fill="#BF5328"
        />
      </Alert>
      <Alert>
        <path
          d="M482.76 295.45l-31.81 1.16c-2.5 0-4.53-1.59-4.53-3.55l-3.66-31.6c0-2 2-3.55 4.53-3.55l35.47.41c2.5 0 4.53 1.59 4.53 3.55v30c0 1.99-2.07 3.58-4.53 3.58z"
          fill="#F58452"
        />
        <path
          d="M439.92 283.31l-2.52-21.71c0-1.68 1.81-3.05 4-3.05h1.7c.6 0 .93-.92 0-1h-1.74c-2.77 0-5 1.82-5 4.11l2.53 21.82c.33.99 1.24.71 1.03-.17z"
          fill="#BF5328"
        />
        <path
          d="M475.51 296.11c.84.05 1-1 .08-1l-30.5 1.12c-2.22 0-4-1.37-4-3.11l-.55-4.73c-.1-.92-1.13-1-1 .08l.54 4.71c0 2.23 2.26 4.05 5 4.05l30.4-1.11.03-.01z"
          fill="#BF5328"
        />
        <path
          d="M481.93 281.04v-9.62c0-.78-1-1.06-1 0v9.69c0 .07.02.13.05.19a.52.52 0 00.3.25.49.49 0 00.37-.03.52.52 0 00.25-.29.49.49 0 00.03-.19z"
          fill="#BF5328"
        />
        <path
          d="M480.93 285.47v6.57a3.04 3.04 0 01-2.11 2.66c-.67.23-.64 1.07 0 1.06a4.14 4.14 0 003.06-3.72v-6.49c.09-.85-.92-1.06-.95-.08z"
          fill="#BF5328"
        />
        <path d="M457.94 279.77l-4.04-18 6.69-.28-.28 18.42-2.37-.14z" fill="#2F1D4A" />
        <path
          d="M459.83 289.54a2.72 2.72 0 100-5.44 2.72 2.72 0 000 5.44z"
          fill="#2F1D4A"
        />
        <path
          d="M447.27 257.91a.64.64 0 00.17.51.64.64 0 00.5.2l29 .34c2.22 0 4 1.37 4 3v3.15c.06 1 1 .8 1 0v-3.1a4.17 4.17 0 00-3.09-3.74l-31.55-.36h-.03z"
          fill="#BF5328"
        />
      </Alert>
      <Alert>
        <path
          d="M451.5 255.3l-21.4.94a3 3 0 01-3-2.87l-2.46-25.52a3 3 0 013-2.87l23.86.33a3 3 0 013 2.87v24.25a3 3 0 01-3 2.87z"
          fill="#F58452"
        />
        <path
          d="M450.32 251.26a2.74 2.74 0 01-2.64 2.83l-22 1.09a2.75 2.75 0 01-2.64-2.87s-1.69-20.58-1.84-21.43c-.15-.85-1-.72-1 0l1.84 21.48a3.75 3.75 0 003.66 3.83l22-1.08a3.74 3.74 0 003.62-3.83V245c0-.85-1-.92-1-.09v6.35z"
          fill="#BF5328"
        />
        <path
          d="M441.9 219.19c-1 .08-18.82-.29-18.82-.29a3.75 3.75 0 00-3.64 3.87l.33 3.86c.15 1 1 .62 1 0s-.33-3.9-.33-3.9a2.74 2.74 0 012.63-2.82s18 .24 18.93.29c.93.05.93-1.09-.1-1.01z"
          fill="#BF5328"
        />
        <path
          d="M447.69 219.28s-1.7-.07-2.67 0-.92 1 .14 1h2.52a2.74 2.74 0 012.64 2.83v17.37c0 .13.05.26.15.35a.5.5 0 00.7 0 .5.5 0 00.15-.35v-17.37a3.74 3.74 0 00-3.63-3.83z"
          fill="#BF5328"
        />
        <path d="M437.55 243.03l-1.56-13 4.98-.21-1.65 13.31-1.77-.1z" fill="#2F1D4A" />
        <path
          d="M438.95 250.28a2.02 2.02 0 100-4.04 2.02 2.02 0 000 4.04z"
          fill="#2F1D4A"
        />
        <path
          d="M450.32 225.29v15.19c0 .13.05.26.15.35a.5.5 0 00.7 0 .5.5 0 00.15-.35v-15.17l-1-.02z"
          fill="#BF5328"
        />
        <path
          d="M450.32 244.89v6.37a2.74 2.74 0 01-2.64 2.83l-20 1a3 3 0 001.26.94l18.77-.93a3.74 3.74 0 003.62-3.83v-6.28c-.01-.88-.98-.88-1.01-.1z"
          fill="#BF5328"
        />
      </Alert>
      <PowerBolts>
        <PowerBolt
          css={css`
            animation-name: ${makeShake()};
          `}
        >
          <path
            d="M114.08 459.21l26.51-7.39s3.35 8.79 3.77 8.65c.42-.14 22.6-2.1 22.6-2.1s-27.34 11.74-27.34 11.31c0-.43-4.19-10.33-4.19-10.33l-21.35-.14z"
            fill="#EBB432"
          />
          <path
            d="M139.89 464.94h-.1a.22.22 0 01-.07-.05.5.5 0 01-.23-.42c-.11-.46-2.47-6.16-4-9.83l-21-.14a.49.49 0 01-.49-.43.5.5 0 01.36-.55l26.47-7.41a.49.49 0 01.6.3c1.36 3.56 3 7.45 3.48 8.3 2.36-.29 16.19-1.52 22.38-2.06a.5.5 0 01.5.72.5.5 0 01-.26.24c-23.71 10.18-26.99 11.33-27.64 11.33zm-21.87-11.41l17.78.11a.5.5 0 01.46.31c2.79 6.6 3.74 9 4.06 9.93 2.35-.8 14.45-5.89 23.93-9.94-8.42.75-18.84 1.69-19.4 1.8-.56.11-.82.28-4.19-8.53l-22.64 6.32zm26.68 1.23h-.13.13z"
            fill="#EBB432"
          />
          <path
            d="M150.22 459.88c-4.78 2-8.66 3.58-9.89 4-.32-.92-1.27-3.33-4.06-9.93a.5.5 0 00-.46-.31h-1.71l-3.51 1h4.89c1.55 3.67 3.91 9.37 4 9.83a.5.5 0 00.23.42c.02.02.05.04.08.04l.09.01c.49 0 2.49-.66 13.66-5.37l-3.32.31z"
            fill="#A67029"
          />
        </PowerBolt>
        <PowerBolt
          css={css`
            animation-name: ${makeShake()};
          `}
        >
          <path
            d="M55.39 451.21L44.36 432.1l-15.35 6.7-11.86-12.98 9.49 20.93 14.79-6.84 13.96 11.3z"
            fill="#EBB432"
          />
          <path
            d="M55.01 447.25a.5.5 0 01-.31-.11l-13.72-11.11-14.5 6.71a.52.52 0 01-.39 0 .55.55 0 01-.28-.26l-9.49-20.93a.5.5 0 01.83-.55l11.62 12.72 15-6.56a.5.5 0 01.63.21l11 19.12a.5.5 0 01-.1.63.52.52 0 01-.29.13zm-13.95-12.31c.11 0 .22.04.31.12l11.86 9.6-9.45-16.39-14.94 6.52a.52.52 0 01-.57-.12l-9.74-10.66 8 17.61 14.34-6.63a.5.5 0 01.19-.05z"
            fill="#EBB432"
          />
          <path
            d="M51.57 444.61l-1.35-2.42-8.85-7.08a.47.47 0 00-.31-.12.5.5 0 00-.21.05l-14.34 6.63-5-11-2.18-2.39 6.47 14.28c.06.12.16.21.28.26.13.05.26.05.39 0l14.5-6.71 10.6 8.5z"
            fill="#A67029"
          />
        </PowerBolt>
        <PowerBolt
          css={css`
            animation-name: ${makeShake()};
          `}
        >
          <path
            d="M116.45 433.11l16-11.58 6 9.35.14-23.17 19.81-7.39-14.32 11.59s-.14 34.6-.7 34.33c-.56-.27-13.11-17-13.11-17l-13.82 3.87z"
            fill="#EBB432"
          />
          <path
            d="M140.41 441.53a.46.46 0 01-.23-.06c-.54-.27-7.36-9.27-13.08-16.89l-13.49 3.81a.48.48 0 01-.58-.26.5.5 0 01.15-.62l16.04-11.59a.47.47 0 01.19-.08.48.48 0 01.2 0 .45.45 0 01.32.22l5.09 7.93.13-21.48a.48.48 0 01.33-.46l19.81-7.4a.5.5 0 01.61.22.5.5 0 01-.12.64l-14.19 11.43c-.14 34-.61 34.32-.92 34.51a.5.5 0 01-.26.08zm-13.12-18a.54.54 0 01.4.2c4.06 5.46 8.2 10.86 12.39 16.22.3-4.21.48-21.47.52-33.22a.52.52 0 01.19-.39l12-9.64-16.6 6.19-.14 22.82a.5.5 0 01-.36.48.51.51 0 01-.56-.21l-5.71-8.91-13.33 9.62 11.09-3.14.11-.02z"
            fill="#EBB432"
          />
          <path
            d="M140.6 406.99c-.05 11.74-.22 28.75-.52 32.93-3.98-5.07-7.9-10.2-11.75-15.37l-.82.59c5.63 7.49 12.14 16.07 12.67 16.33.07.04.15.06.23.06a.5.5 0 00.27-.08c.31-.19.78-.48.92-34.51l.75-.6-1.75.65z"
            fill="#A67029"
          />
          <path
            d="M132.5 421.54l-.16.11 2.76 4.3a.5.5 0 00.36.2l-2.96-4.61z"
            fill="#A67029"
          />
        </PowerBolt>
      </PowerBolts>
      <Sparks>
        <Spark
          css={css`
            animation-name: ${makeOpacityJitter()};
          `}
        >
          <path
            d="M249.66 498.04a.5.5 0 01-.31-.11l-6.56-5.31a.49.49 0 01-.08-.7.51.51 0 01.71-.07l6.56 5.3a.5.5 0 01-.03.8.5.5 0 01-.29.09z"
            fill="#A67029"
          />
          <path
            d="M243.38 505.11c-.1 0-.2-.03-.28-.08a.49.49 0 01-.22-.42.5.5 0 01.32-.46l5.3-2.09a.49.49 0 01.65.28c.02.06.04.13.04.2a.5.5 0 01-.32.45l-5.3 2.09a.61.61 0 01-.19.03z"
            fill="#A67029"
          />
          <path
            d="M253.29 510.6a.5.5 0 01-.48-.37l-1.82-6.56a.52.52 0 011-.27l1.81 6.56a.51.51 0 01-.35.62l-.16.02z"
            fill="#A67029"
          />
          <path
            d="M247.35 498.11a.56.56 0 01-.32-.11l-4.61-3.74a.5.5 0 11.63-.78l4.61 3.74a.5.5 0 01-.1.84.54.54 0 01-.21.05z"
            fill="#EBB432"
          />
          <path
            d="M244.22 507.11a.51.51 0 01-.59-.6.51.51 0 01.41-.4l5.3-2.09a.49.49 0 01.65.28.51.51 0 01-.28.65l-5.31 2.16a.4.4 0 01-.18 0z"
            fill="#EBB432"
          />
          <path
            d="M255.22 512.27a.5.5 0 01-.48-.37l-1.81-6.56a.49.49 0 01.35-.61.5.5 0 01.61.35l1.81 6.56a.5.5 0 01-.04.38.5.5 0 01-.3.23l-.14.02z"
            fill="#EBB432"
          />
        </Spark>
        <Spark
          css={css`
            animation-name: ${makeOpacityJitter()};
          `}
        >
          <path
            d="M251.06 478.5a.5.5 0 01-.37-.16l-7-7.53a.51.51 0 010-.71c.05-.05.1-.08.16-.1a.49.49 0 01.39 0c.06.02.11.05.16.1l7 7.53a.49.49 0 01.1.54.5.5 0 01-.46.3l.02.03z"
            fill="#A67029"
          />
          <path
            d="M247.15 481.71c-2.7-.09-7.89-.28-8.21-.28a.5.5 0 01-.35-.15.5.5 0 010-.7.5.5 0 01.35-.15c.42 0 7.93.27 8.25.28a.5.5 0 01.35.15.5.5 0 010 .7.5.5 0 01-.35.15h-.04z"
            fill="#A67029"
          />
          <path
            d="M250.64 490.78h-.09a.5.5 0 01-.4-.58l1.11-6.14a.51.51 0 01.58-.4.5.5 0 01.41.58l-1.12 6.14a.49.49 0 01-.49.4z"
            fill="#A67029"
          />
          <path
            d="M249.16 478.56a.5.5 0 01-.37-.16l-4.89-5.36a.5.5 0 01-.1-.55.5.5 0 01.8-.16l4.89 5.36a.49.49 0 01.1.54.5.5 0 01-.46.3l.03.03z"
            fill="#EBB432"
          />
          <path
            d="M245.45 483.77c-2.7-.1-5.26-.29-5.58-.29a.5.5 0 01-.35-.15.5.5 0 010-.7.5.5 0 01.35-.15c.42 0 5.3.28 5.62.29a.5.5 0 01.35.15.5.5 0 010 .7.5.5 0 01-.35.15h-.04z"
            fill="#EBB432"
          />
          <path
            d="M252.1 490.32h-.09a.5.5 0 01-.4-.58l.61-3.63a.51.51 0 01.58-.4.5.5 0 01.41.58l-.59 3.63a.5.5 0 01-.52.4z"
            fill="#EBB432"
          />
        </Spark>
        <Spark
          css={css`
            animation-name: ${makeOpacityJitter()};
          `}
        >
          <path
            d="M451.99 95.34a.5.5 0 01-.49-.38.5.5 0 01.36-.6c.42-.11 5.87-2.22 9.43-3.61a.5.5 0 01.64.66.5.5 0 01-.27.27c-.92.36-9 3.5-9.55 3.65l-.12.01z"
            fill="#A67029"
          />
          <path
            d="M460.64 109.99c-.1 0-.2-.03-.28-.08l-7.95-5.3a.5.5 0 01.55-.84l8 5.31a.5.5 0 01.2.55.5.5 0 01-.47.36h-.05z"
            fill="#A67029"
          />
          <path
            d="M456.31 117.95a.53.53 0 01-.42-.23l-6.14-9.49a.5.5 0 01.53-.76.5.5 0 01.31.22l6.14 9.48a.5.5 0 01.03.52.5.5 0 01-.45.26z"
            fill="#A67029"
          />
          <path
            d="M452.99 97.34a.5.5 0 01-.49-.38.5.5 0 01.36-.6c.42-.11 5.87-2.22 9.43-3.61a.5.5 0 01.64.66.5.5 0 01-.27.27c-.92.36-9 3.5-9.55 3.65l-.12.01z"
            fill="#EBB432"
          />
          <path
            d="M456.76 109.7c-.1 0-.2-.03-.28-.08l-4.77-3.06a.5.5 0 01-.21-.32.5.5 0 01.4-.6.5.5 0 01.37.08l4.76 3.06a.49.49 0 01.22.32.5.5 0 01-.49.6z"
            fill="#EBB432"
          />
          <path
            d="M454.06 117.73a.52.52 0 01-.42-.23l-4.72-7.46a.5.5 0 01-.09-.39.5.5 0 01.23-.32.49.49 0 01.18-.08.5.5 0 01.39.1c.05.04.1.1.13.15l4.72 7.46a.5.5 0 01-.15.69.53.53 0 01-.27.08z"
            fill="#EBB432"
          />
        </Spark>
        <Spark
          css={css`
            animation-name: ${makeOpacityJitter()};
          `}
        >
          <path
            d="M447.66 68.27a.5.5 0 01-.34-.13.51.51 0 010-.71l8.24-8.93a.5.5 0 01.7.71l-8.23 8.9a.5.5 0 01-.37.16z"
            fill="#A67029"
          />
          <path
            d="M451.71 71.62a.5.5 0 01-.43-.82.5.5 0 01.34-.18l11.6-2.09a.5.5 0 01.58.41.5.5 0 01-.4.58l-11.6 2.09-.09.01z"
            fill="#A67029"
          />
          <path
            d="M457.85 87.81a.53.53 0 01-.31-.11l-6.41-4.88a.5.5 0 01-.1-.7.5.5 0 01.7-.1l6.42 4.89a.5.5 0 01.2.33c0 .07 0 .13-.02.2a.5.5 0 01-.09.17.47.47 0 01-.39.2z"
            fill="#A67029"
          />
          <path
            d="M448.66 70.27a.5.5 0 01-.34-.13.51.51 0 010-.71l7.12-7.68a.5.5 0 11.73.68l-7.14 7.68a.5.5 0 01-.37.16z"
            fill="#EBB432"
          />
          <path
            d="M452.71 73.62a.5.5 0 01-.54-.45.5.5 0 01.11-.37.5.5 0 01.34-.18l9-1.73a.5.5 0 11.18 1l-9 1.73h-.09z"
            fill="#EBB432"
          />
          <path
            d="M454.56 87.85a.48.48 0 01-.3-.11l-3.23-2.45a.5.5 0 11.61-.8l3.22 2.46a.5.5 0 01-.3.9z"
            fill="#EBB432"
          />
        </Spark>
      </Sparks>
    </svg>
  );
}

export default NoProjectEmptyState;
